for (int Ecorr=0; Ecorr<nEnergyCorrectors; Ecorr++)
{
    fluid.correctEnergyTransport();

    autoPtr<phaseSystem::heatTransferTable>
        heatTransferPtr(fluid.heatTransfer());

    PtrList<fvScalarMatrix> EEqns(fluid.anisothermalPhases().size());

    forAll(fluid.anisothermalPhases(), anisothermalPhasei)
    {
        phaseModel& phase = fluid.anisothermalPhases()[anisothermalPhasei];

        const volScalarField& alpha = phase;
        tmp<volScalarField> tRhoAlpha = phase.rho();
        const volScalarField& rhoAlpha = tRhoAlpha();
        tmp<volVectorField> tUAlpha = phase.U();
        const volVectorField& UAlpha = tUAlpha();

        EEqns.set
        (
            anisothermalPhasei,
            (
                phase.heEqn()
             ==
                alpha*rhoAlpha*(UAlpha & g)
              + fvModels.source(alpha, rhoAlpha, phase.thermoRef().he())
            )
        );

        EEqns[anisothermalPhasei] +=
            fvm::ddt
            (
                max(phase.residualAlpha() - alpha, Zero)*rhoAlpha,
                phase.thermoRef().he()
            )
          - fvc::ddt
            (
                max(phase.residualAlpha() - alpha, Zero)*rhoAlpha,
                phase.thermoRef().he()
            );
    }

    if (energyPartialElimination)
    {
        volScalarField HESum
        (
            IOobject
            (
                "HESum",
                runTime.timeName(),
                mesh
            ),
            mesh,
            dimensionedScalar(dimensionSet(1, -1, -3, 0, 0), Zero)
        );

        forAll(fluid.anisothermalPhases(), anisothermalPhasei)
        {
            HESum += EEqns[anisothermalPhasei].H();
        }

        PtrList<volScalarField> heatTransferDiag
        (
            fluid.anisothermalPhases().size()
        );
        PtrList<volScalarField> heatTransferSource
        (
            fluid.anisothermalPhases().size()
        );
        initZeroPtrList
        (
            heatTransferDiag,
            mesh,
            dimensionSet(1, -3, -1, 0, 0),
            "heatTransferDiag"
        );
        initZeroPtrList
        (
            heatTransferSource,
            mesh,
            dimensionSet(1, -1, -3, 0, 0),
            "heatTransferSource"
        );

        forAllConstIter(phaseSystem::KeTable, fluid.Kes(), KeIter)
        {
            const volScalarField& K(*KeIter());
            const phaseInterface interface(fluid, KeIter.key());

            forAllConstIter(phaseInterface, interface, interfaceIter)
            {
                const phaseModel& phase = interfaceIter();
                const phaseModel& otherPhase = interfaceIter.otherPhase();

                const volScalarField rCpvAEsBeta
                (
                    1.0
                   /(otherPhase.thermo().Cpv()*EEqns[otherPhase.index()].A())
                );

                heatTransferDiag[phase.index()] +=
                    K
                   *(
                        1.0/phase.thermo().Cpv()
                      + EEqns[phase.index()].A()*rCpvAEsBeta
                    );

                heatTransferSource[phase.index()] += K*rCpvAEsBeta*HESum;
            }
        }

        forAll(fluid.anisothermalPhases(), anisothermalPhasei)
        {
            phaseModel& phase = fluid.anisothermalPhases()[anisothermalPhasei];

            EEqns[anisothermalPhasei] +=
                fvm::Sp
                (
                    heatTransferDiag[anisothermalPhasei],
                    phase.thermoRef().he()
                )
              - heatTransferSource[anisothermalPhasei];
        }
    }
    else
    {
        forAll(fluid.anisothermalPhases(), anisothermalPhasei)
        {
            const phaseModel& phase =
                fluid.anisothermalPhases()[anisothermalPhasei];
            EEqns[anisothermalPhasei] -= *heatTransferPtr()[phase.name()];
        }
    }


    forAll(fluid.anisothermalPhases(), anisothermalPhasei)
    {
        phaseModel& phase = fluid.anisothermalPhases()[anisothermalPhasei];

        fvScalarMatrix& EEqn = EEqns[anisothermalPhasei];

        EEqn.relax();
        fvConstraints.constrain(EEqn);
        EEqn.solve();
        fvConstraints.constrain(phase.thermoRef().he());
    }

    fluid.correctThermo();
    fluid.correctContinuityError();
}


forAll(fluid.anisothermalPhases(), phasei)
{
    const phaseModel& phase = fluid.anisothermalPhases()[phasei];

    Info<< phase.name() << " min/max T "
        << min(phase.thermo().T()).value()
        << " - "
        << max(phase.thermo().T()).value()
        << endl;
}
