forAll(fluid.movingPhases(), movingPhasei)
{
    phaseModel& phase = fluid.movingPhases()[movingPhasei];
    volVectorField& UAlpha = phase.URef();
    const volScalarField& alpha = phase;
    const volScalarField& rhoAlpha = phase.thermoRef().rho();

    HUEqns.set
    (
        phase.index(),
        (
            fvm::div(phase.alphaRhoPhi(), UAlpha)
          + phase.divDevTau(UAlpha)
          + fvm::SuSp(- fvc::div(phase.alphaRhoPhi()), UAlpha)
          + MRF.DDt(alpha*rhoAlpha, UAlpha)
        )
    );
}

// Create U & grad(U) fields
PtrList<fvVectorMatrix> UgradUs(phases.size());
forAll(fluid.movingPhases(), movingPhasei)
{
    const phaseModel& phase = fluid.movingPhases()[movingPhasei];
    const volVectorField& UAlpha = phase.U();
    const surfaceScalarField& phiAlpha = phase.phi();

    UgradUs.set
    (
        phase.index(),
        new fvVectorMatrix
        (
            fvm::div(phiAlpha, UAlpha)
          + fvm::SuSp(- fvc::div(phiAlpha), UAlpha)
        )
    );
}

// Add convective part of the virtual mass force
forAllConstIter(phaseSystem::VmTable, fluid.Vms(), VmIter)
{
    const volScalarField& Vm(*VmIter());
    const phaseInterface interface(fluid, VmIter.key());

    forAllConstIter(phaseInterface, interface, interfaceIter)
    {
        const phaseModel& phase = interfaceIter();
        const phaseModel& otherPhase = interfaceIter.otherPhase();

        HUEqns[phase.index()] +=
            Vm
           *(
                UgradUs[phase.index()]
              - (UgradUs[otherPhase.index()] & otherPhase.U())
            );
    }
}

// Relaxation factor
forAll(fluid.movingPhases(), movingPhasei)
{
    const phaseModel& phase = fluid.movingPhases()[movingPhasei];

    const word name =
        HUEqns[phase.index()].psi().select(pimple.finalPimpleIter());

    relaxU[phase.index()] = 1;

    if (fluid.mesh().solution().relaxField(name))
    {
        relaxU[phase.index()] =
            fluid.mesh().solution().fieldRelaxationFactor(name);

        if (pimple.finalPimpleIter() && relaxU[phase.index()] != 1)
        {
            Warning << "Field relaxation factor of " << relaxU[phase.index()]
                    << " for solution variable '" << name
                    << "' is not recommended." << endl << endl;
        }
    }
}
