forAll(fluid.movingPhases(), movingPhasei)
{
    const phaseModel& phase = fluid.movingPhases()[movingPhasei];
    const volVectorField& UAlpha = phase.U();
    const PtrList<volScalarField> dmdts = fluid.dmdts();

    const dimensionedScalar ZERO(dimensionSet(1, -3, -1, 0, 0), Zero);

    dmdtUEqns.set
    (
        phase.index(),
        (
            fvm::Sp(ZERO, UAlpha)
          + fvm::Su(Zero, UAlpha)
        )
    );

    volScalarField source
    (
        volScalarField::New
        (
            IOobject::groupName("source", phase.name()),
            mesh,
            dimensionedScalar(dimDensity/dimTime, 0)
        )
    );

    if (fvModels.addsSupToField(rho.name()))
    {
        source += fvModels.source(phase, rho)&rho;
    }

    if (dmdts.set(phase.index()))
    {
        source += dmdts[phase.index()];
    }

    dmdtUEqns[phase.index()] += fvm::SuSp(source, UAlpha);
}

initZeroPtrList
(
    dmdtPhiCoeffs,
    mesh,
    dimensionSet(1, 0, -2, 0, 0),
    "dmdtPhiCoeff"
);

// Add mass sources
// Inspired by MomentumTransferPhaseSystem::addDmdtUfs() but with fvm::SuSp()
// instead of fvm::Sp()
{
    autoPtr<phaseSystem::dmdtfTable> dmdtfsPtr(fluid.dmdtfs());

    forAllConstIter(phaseSystem::dmdtfTable, dmdtfsPtr(), dmdtfIter)
    {
        const phaseInterface interface(fluid, dmdtfIter.key());

        const volScalarField& dmdtf(*dmdtfIter());
        const volScalarField dmdtf21(posPart(dmdtf));
        const volScalarField dmdtf12(negPart(dmdtf));

        phaseModel& phase1 = fluid.phases()[interface.phase1().name()];
        phaseModel& phase2 = fluid.phases()[interface.phase2().name()];

        if (!phase1.stationary())
        {
            dmdtUEqns[phase1.index()] -=
                pos(phase1 - phase1.residualAlpha())*dmdtf21*phase2.U()
              + fvm::SuSp(dmdtf12, phase1.URef());

            dmdtPhiCoeffs[phase1.index()] +=
                pos(alphafs[phase1.index()] - phase1.residualAlpha())
               *fvc::interpolate(dmdtf21)*MRF.absolute(phase2.phi());
        }

        if (!phase2.stationary())
        {
            dmdtUEqns[phase2.index()] +=
                pos(phase2 - phase2.residualAlpha())*dmdtf12*phase1.U()
              - fvm::SuSp(-dmdtf21, phase2.URef());

            dmdtPhiCoeffs[phase2.index()] -=
                pos(alphafs[phase2.index()] - phase2.residualAlpha())
               *fvc::interpolate(dmdtf12)*MRF.absolute(phase1.phi());
        }
    }
}
