initZeroPtrList(dragSourcef, mesh, dimensionSet(0, 3, -1, 0, 0), "dragSourcef");

{
    // Summed RHS of face-based momentum balance equation
    surfaceScalarField HSumf
    (
        IOobject
        (
            "HSumf",
            runTime.timeName(),
            mesh
        ),
        mesh,
        dimensionedScalar(dimensionSet(1, 0, -2, 0, 0), Zero)
    );

    if (partialElimination)
    {
        forAll(fluid.movingPhases(), movingPhasei)
        {
            const phaseModel& phase = fluid.movingPhases()[movingPhasei];

            HSumf +=
                fvc::flux(HUEqns[phase.index()].H())
              + ddtPhiCoeffs[phase.index()]
              + fvc::flux(fvModelsEqns[phase.index()].H());
        }
    }

    forAllConstIter(phaseSystem::KdfTable, fluid.Kdfs(), KdfIter)
    {
        const surfaceScalarField& Kf(*KdfIter());
        const phaseInterface interface(fluid, KdfIter.key());

        forAllConstIter(phaseInterface, interface, interfaceIter)
        {
            const phaseModel& phase = interfaceIter();
            const phaseModel& otherPhase = interfaceIter.otherPhase();

            if (phase.stationary() || otherPhase.stationary()) continue;

            if (partialElimination)
            {
                dragSourcef[phase.index()]
                    += Kf*rAfs[otherPhase.index()]*rHUfs[phase.index()]*HSumf;

                forAll(fluid.movingPhases(), movingPhasei)
                {
                    const phaseModel& remainingPhase =
                        fluid.movingPhases()[movingPhasei];

                    if
                    (
                        (remainingPhase.index() == phase.index())
                     || (remainingPhase.index() == otherPhase.index())
                    ) continue;

                    dragSourcef[phase.index()] -=
                    (
                        Kf*rAfs[otherPhase.index()]*rHUfs[phase.index()]
                       *(
                            fvc::interpolate(HUEqns[remainingPhase.index()].A())
                          + fvc::interpolate
                            (
                                ddtUEqns[remainingPhase.index()].A()
                            )
                          + fvc::interpolate
                            (
                                fvModelsEqns[remainingPhase.index()].A()
                            )
                        )
                       *MRF.absolute(phases[remainingPhase.index()].phi())
                    );
                }
            }
            else
            {
                dragSourcef[phase.index()]
                    += Kf*rHUfs[phase.index()]
                      *MRF.absolute(phases[otherPhase.index()].phi());
            }
        }
    }
}
