initZeroPtrList
(
    forcesSourcef, mesh, dimensionSet(1, 0, -2, 0, 0), "forcesSourcef"
);

// Add lift force
// Inspired by MomentumTransferPhaseSystem::phiFfs()
forAllConstIter(phaseSystem::FlfTable, fluid.Flfs(), FlfIter)
{
    const surfaceScalarField& Ff(*FlfIter());
    const phaseInterface interface(fluid, FlfIter.key());

    forcesSourcef[interface.phase1().index()] -= Ff;
    forcesSourcef[interface.phase2().index()] += Ff;
}

// Add wall lubrication force
// Inspired by MomentumTransferPhaseSystem::phiFfs()
forAllConstIter(phaseSystem::FwfTable, fluid.Fwfs(), FwfIter)
{
    const surfaceScalarField& Ff(*FwfIter());
    const phaseInterface interface(fluid, FwfIter.key());

    forcesSourcef[interface.phase1().index()] -= Ff;
    forcesSourcef[interface.phase2().index()] += Ff;
}

// Add turbulent dispersion force
// Inspired by MomentumTransferPhaseSystem::phiFfs()
forAllConstIter(phaseSystem::DtTable, fluid.Dts(), DtIter)
{
    const volScalarField& D(*DtIter());
    const phaseInterface interface(fluid, DtIter.key());

    const phaseModel& phase1(interface.phase1());
    const phaseModel& phase2(interface.phase2());

    const surfaceScalarField alphaf12
    (
        max
        (
            alphafs[phase1.index()] + alphafs[phase2.index()],
            phase1.residualAlpha() + phase2.residualAlpha()
        )
    );

    const surfaceScalarField Ff
    (
        fvc::interpolate(D)
       *segregatedPhaseInterface(phase1, phase2).gradAlphaf()
       /sqr(alphaf12)*phase1.mesh().magSf()
    );

    forcesSourcef[phase1.index()] -= Ff;
    forcesSourcef[phase2.index()] += Ff;
}
