/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2019-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::subGridSurfaceTensionModel::scaleSimilaritySubGridSurfaceTension

Description
    Sub grid surface tension with scale similarity approach incorporating a test
    filter operation.

    Reference:
    \verbatim
        Ketterl, S., Reißmann, M., Klein, M. (2019).
        Large eddy simulation of multiphase flows using the volume of fluid
        method: Part 2 - A-posteriori analysis of liquid jet atomization.
        Experimental and Computational Multiphase Flow, 1(3), 201-211.
    \endverbatim

SourceFiles
    scaleSimilaritySubGridSurfaceTension.C

\*---------------------------------------------------------------------------*/

#ifndef scaleSimilaritySubGridSurfaceTension_H
#define scaleSimilaritySubGridSurfaceTension_H

#include "subGridSurfaceTensionModel.H"
#include "simpleFilter.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace subGridSurfaceTensionModels
{

/*---------------------------------------------------------------------------*\
            Class scaleSimilaritySubGridSurfaceTension Declaration
\*---------------------------------------------------------------------------*/

class scaleSimilaritySubGridSurfaceTension
:
    public subGridSurfaceTensionModel
{
    // Private Data

        //- Sub grid filter
        autoPtr<LESfilter> filterPtr_;

        //- Access to sub grid filter
        LESfilter& filter_;


    // Private Member Functions

        //- Sub grid surface tension force
        virtual tmp<volVectorField> subGridSurfaceTensionForce() const;


public:

    //- Runtime type information
    TypeName("scaleSimilarity");


    // Constructors

        //- Construct from a dictionary and an interface
        scaleSimilaritySubGridSurfaceTension
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~scaleSimilaritySubGridSurfaceTension();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace subGridSurfaceTensionModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
