/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2018-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::dragModels::StrubeljTiselj

Description
    Numerical drag for handling of resolved interfaces in multi-fluid model

    \verbatim
        Strubelj, L. and Tiselj, I. 'Two-fluid model with interface sharpening'
        International Journal for Numerical Methods in Engineering, Vol. 85,
        pp. 575-590 (2011)
    \endverbatim

SourceFiles
    StrubeljTiselj.C

\*---------------------------------------------------------------------------*/

#ifndef StrubeljTiselj_H
#define StrubeljTiselj_H

#include "dragModel.H"
#include "segregatedPhaseInterface.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace dragModels
{

/*---------------------------------------------------------------------------*\
                       Class StrubeljTiselj Declaration
\*---------------------------------------------------------------------------*/

class StrubeljTiselj
:
    public dragModel
{
    // Private Data

        //- Interface
        const segregatedPhaseInterface interface_;

        //- Ratio of physical time step to relaxation time
        const dimensionedScalar tau_;


public:

    //- Runtime type information
    TypeName("StrubeljTiselj");


    // Constructors

        //- Construct from a dictionary and an interface
        StrubeljTiselj
        (
            const dictionary& dict,
            const phaseInterface& interface,
            const bool registerObject
        );


    //- Destructor
    virtual ~StrubeljTiselj();


    // Member Functions

        //- Return the drag coefficient K as a scalar
        //  used in the momentum equations
        //    ddt(alpha1*rho1*U1) + ... = ... K*(U1-U2)
        //    ddt(alpha2*rho2*U2) + ... = ... K*(U2-U1)
        virtual tmp<volScalarField> K() const;

        //- Return the drag coefficient Kf
        //  used in the face-momentum equations
        virtual tmp<surfaceScalarField> Kf() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace dragModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
