/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2018-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::dragModels::linearDrag

Description
    Numerical drag model that returns a constant drag coefficient, independent
    from relative velocity. Therefore this numerical drag model behaves
    linearly.

Interfacial momentum transfer due to drag
\f[
    \vec{M}_d = -\vec{M}_c = K\,\left(\vec{U}_c-\vec{U}_d\right)
\f]

Dragfunction K
\f[
    K = \alpha_d Ki
\f]

Usage
    \table
        Parameter   | Name  | Description       | Default value
        \f$Ki\f$    | Ki    | drag coefficient  | -
    \endtable

SourceFiles
    linearDrag.C

\*---------------------------------------------------------------------------*/

#ifndef linearDrag_H
#define linearDrag_H

#include "dispersedDragModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace dragModels
{

/*---------------------------------------------------------------------------*\
                         Class linearDrag Declaration
\*---------------------------------------------------------------------------*/

class linearDrag
:
    public dispersedDragModel
{
    // Private Data

        //- Drag coefficient
        const dimensionedScalar ki_;

public:

    //- Runtime type information
    TypeName("linearDrag");


    // Constructors

        //- Construct from a dictionary and an interface
        linearDrag
        (
            const dictionary& dict,
            const phaseInterface& interface,
            const bool registerObject
        );


    //- Destructor
    virtual ~linearDrag();


    // Member Functions

        //- Drag coefficient
        virtual tmp<volScalarField> CdRe() const;

        //- Return the phase-intensive drag coefficient Ki
        //  used in the momentum equations
        virtual tmp<volScalarField> Ki() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace dragModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
