/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf
    and some other institution

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::dragModels::wallDampedDrag

Description
    Wall-damped drag model.
    Ongoing and unpublished work related to wall damping by Rzehak et al.

SourceFiles
    wallDampedDrag.C

\*---------------------------------------------------------------------------*/

#ifndef wallDampedDrag_H
#define wallDampedDrag_H

#include "dispersedDragModel.H"
#include "wallDampingModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace dragModels
{

/*---------------------------------------------------------------------------*\
                       Class wallDampedDrag Declaration
\*---------------------------------------------------------------------------*/

class wallDampedDrag
:
    public dispersedDragModel
{
    // Private Data

        //- The drag model to damp
        autoPtr<dragModel> dragModel_;

        //- The wall-damping model
        autoPtr<wallDampingModel> wallDampingModel_;

        //- Artificial minimum value for Ki
        const dimensionedScalar Kmin_;


public:

    //- Runtime type information
    TypeName("wallDamped");


    // Constructors

        //- Construct with residual constants
        wallDampedDrag
        (
            const dictionary& dict,
            const phaseInterface& interface,
            const bool registerObject
        );


    //- Destructor
    virtual ~wallDampedDrag();


    // Member Functions

        //- Return drag coefficient
        virtual tmp<volScalarField> CdRe() const;

        //- Return the phase-intensive drag coefficient Ki
        //  used in the momentum equations
        virtual tmp<volScalarField> Ki() const;

        //- Return the drag coefficient K
        //  used in the momentum equations
        virtual tmp<volScalarField> K() const;

        //- Return the drag coefficient Kf
        //  used in the face-momentum equations
        virtual tmp<surfaceScalarField> Kf() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace dragModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
