/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2018-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::inducedTurbulenceModels::Ma

Description
    Bubble-induced turbulence model of Ma et al. (2017).

    Reference:
    \verbatim
        Ma, T., Santarelli, C., Ziegenhein, T., Lucas, D., &
        Fröhlich, J. (2017).
        Direct numerical simulation–based Reynolds-averaged closure for
        bubble-induced turbulence.
        Physical Review Fluids, 2(3), 034301.
    \endverbatim


SourceFiles
    Ma.C

\*---------------------------------------------------------------------------*/

#ifndef Ma_H
#define Ma_H

#include "inducedTurbulenceModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace inducedTurbulenceModels
{

/*---------------------------------------------------------------------------*\
                             Class Ma Declaration
\*---------------------------------------------------------------------------*/

class Ma
:
    public inducedTurbulenceModel
{
protected:

    // Protected Member Functions

        //- Phase interface
        const dispersedPhaseInterface dispersedInterface_;

        //- Induced turbulence kinetic energy coefficient
        virtual tmp<volScalarField> Ck() const;

        //- Induced turbulence dissipation rate coefficient
        virtual tmp<volScalarField> Ceps() const;


public:

    //- Runtime type information
    TypeName("Ma");


    // Constructors

        //- Construct from a dictionary and an interface
        Ma
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~Ma();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace inducedTurbulenceModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
