/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2020-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::liftModels::ShiRzehakLift

Description
    Lift model of Shi and Rzehak (2020).

    References:
    \verbatim
        Shi, P., & Rzehak, R. (2020).
        Solid-liquid flow in stirred tanks: Euler-Euler / RANS modeling.
        Chemical Engineering Science, 227, 115875.
    \endverbatim

    Note: A lower limit of 0.1 is added to the rotation rate function fOmega to
          prevent negative values in high Re regions.

SourceFiles
    ShiRzehakLift.C

\*---------------------------------------------------------------------------*/

#ifndef ShiRzehakLift_H
#define ShiRzehakLift_H

#include "dispersedLiftModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace liftModels
{

/*---------------------------------------------------------------------------*\
                        Class ShiRzehakLift Declaration
\*---------------------------------------------------------------------------*/

class ShiRzehakLift
:
    public dispersedLiftModel
{
    // Private Data

        //- Residual Reynolds number
        const dimensionedScalar residualRe_;


public:

    //- Runtime type information
    TypeName("ShiRzehak");


    // Constructors

        //- Construct from a dictionary and an interface
        ShiRzehakLift
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~ShiRzehakLift();


    // Member Functions

        //- Lift coefficient
        virtual tmp<volScalarField> Cl() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace liftModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
