/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2019-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::phaseTransferModels::Ma

Description
    Entrainment model of Ma et al.

    References:
    \verbatim
        Ma, J., Oberai, A. A., Drew, D. A., Lahey Jr., R. T., Hyman, M. C.
        (2011).
        A Comprehensive Sub-Grid Air Entrainment Model for RANS Modeling of
        Free-Surface Bubbly Flows.
        Journal of Computational Multiphase Flows.
    \endverbatim

Usage
    \table
        Property    | Description                          | Required | Default
        threshold   | Minimum entraining phase fraction    | no       | 0.2
        Cent        | Bubble source intensity              | no       | 1
        phiEnt      | Entrainment layer thickness          | no       | 1
    \endtable

SourceFiles
    MaEntrainment.C

\*---------------------------------------------------------------------------*/

#ifndef MaEntrainment_H
#define MaEntrainment_H

#include "entrainmentModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace phaseTransferModels
{

/*---------------------------------------------------------------------------*\
                             Class Ma Declaration
\*---------------------------------------------------------------------------*/

class Ma
:
    public entrainmentModel
{
    // Private Data

        //- Bubble source intensity
        const dimensionedScalar Cent_;

        //- Thickness of entrainment layer
        const dimensionedScalar phiEnt_;


protected:

    // Protected Member Functions

        //- Returns the mass transfer rate
        virtual tmp<volScalarField> rate(const phaseModel&) const;


public:

    //- Runtime type information
    TypeName("MaEntrainment");


    // Constructors

        //- Construct from components
        Ma
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~Ma();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace phaseTransferModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
