/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2019-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::phaseTransferModels::Moraga

Description
    Entrainment model of Moraga et al.

    Reference:
    \verbatim
        Moraga, F. J., Carrica, P. M., Drew, D. A., Lahey Jr., R. T. (2008).
        A Sub-Grid Air Entrainment Model for Breaking Bow Waves and Naval
        Surface Ships.
        Computers and Fluids.
    \endverbatim

Usage
    \table
        Property    | Description                          | Required | Default
        threshold   | Minimum entraining phase fraction    | no       | 0.2
        S0          | Bubble source intensity              | no       | 1
        UEntrainment| Entrainment velocity threshold       | no       | 0.22
    \endtable

SourceFiles
    MoragaEntrainment.C

\*---------------------------------------------------------------------------*/

#ifndef MoragaEntrainment_H
#define MoragaEntrainment_H

#include "entrainmentModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace phaseTransferModels
{

/*---------------------------------------------------------------------------*\
                           Class Moraga Declaration
\*---------------------------------------------------------------------------*/

class Moraga
:
    public entrainmentModel
{
    // Private Data

        //- Bubble source intensity
        const dimensionedScalar S0_;

        //- Entrainment velocity threshold
        const dimensionedScalar Uent_;


protected:

    // Protected Member Functions

        //- Returns the mass transfer rate
        virtual tmp<volScalarField> rate(const phaseModel&) const;


public:

    //- Runtime type information
    TypeName("MoragaEntrainment");


    // Constructors

        //- Construct from components
        Moraga
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~Moraga();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace phaseTransferModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
