/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::phaseTransferModels::disintegrationToDisperse

Description
    Morphology transfer model representing change from a under-resolved
    continuous phase to a disperse phase. The dominant continuous phase is
    locally excluded from this transfer. Furthermore, a minimal local sum of all
    continuous phases is required to increase numerical stability.

Usage
    \table
        Property           | Description                   | Required | Default
        continuousThreshold|Minimal required sum of continuous phases| no| 0.5
    \endtable

See also
    Foam::phaseTransferModels::morphologyTransferModel

SourceFiles
    disintegrationToDisperse.C

\*---------------------------------------------------------------------------*/

#ifndef disintegrationToDisperse_H
#define disintegrationToDisperse_H

#include "morphologyTransferModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace phaseTransferModels
{

/*---------------------------------------------------------------------------*\
                   Class disintegrationToDisperse Declaration
\*---------------------------------------------------------------------------*/

class disintegrationToDisperse
:
    public morphologyTransferModel
{
    // Private Data

        //- Continuous member of phase pair
        const phaseModel& pairContinuous_;

        //- Threshold of sum of continuous phases to activate transfer
        const scalar contThreshold_;


protected:

    // Protected Member Functions

        //- Return rate
        virtual tmp<volScalarField> rate(const phaseModel&) const;


public:

    //- Runtime type information
    TypeName("disintegrationToDisperse");


    // Constructors

        //- Construct from components
        disintegrationToDisperse
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~disintegrationToDisperse();


    // Member Functions

        //- The mass transfer rate for the mixture
        virtual tmp<volScalarField> dmdtf() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace phaseTransferModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
