/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::phaseTransferModels::superposition

Description
    Superimpose an arbitrary number of phase transfer models. Mass transfer
    rates of individually specified sub-models are summed up.

Usage
    \table
        Property    | Description                       | Required  | Default
        models      | List of models to be superimposed | yes       | -
    \endtable

SourceFiles
    superposition.C

\*---------------------------------------------------------------------------*/

#ifndef superposition_H
#define superposition_H

#include "phaseTransferModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace phaseTransferModels
{

/*---------------------------------------------------------------------------*\
                        Class superposition Declaration
\*---------------------------------------------------------------------------*/

class superposition
:
    public phaseTransferModel
{
    // Private Data

        //- Interface
        const phaseInterface interface_;

        //- List of names of phase transfer model
        const wordList modelNames_;

        //- Phase transfer models
        PtrList<phaseTransferModel> models_;


public:

    //- Runtime type information
    TypeName("superposition");


    // Constructors

        //- Construct from components
        superposition
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~superposition();


    // Member Functions

        //- Whether or not there is a mass transfer rate for the mixture
        virtual bool mixture() const;

        //- The mass transfer rate for the mixture
        virtual tmp<volScalarField> dmdtf() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace phaseTransferModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
