/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::swarmCorrections::polynomialBlendout

Description
    Mathematical swarm correction model to blend out interfacial models if
    phase fraction for dispersed phase runs out of scope. The swarm correction
    factor is multiplied to the coefficient of the interfacial model.

Usage
    \table
        Name | Description | Default
        alphaOnset | Dispersed phase fraction to start model blending  | 0.5
        range | Relative range for reducing swarm correction factor | 0.1
        residualValue | Minimum swarm correction factor | 0.1
    \endtable

SourceFiles
    polynomialBlendout.C

\*---------------------------------------------------------------------------*/

#ifndef polynomialBlendout_H
#define polynomialBlendout_H

#include "swarmCorrection.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace swarmCorrections
{

/*---------------------------------------------------------------------------*\
                     Class polynomialBlendout Declaration
\*---------------------------------------------------------------------------*/

class polynomialBlendout
:
    public swarmCorrection
{
    // Private Data

        //- Maximum phase fraction to start blending out
        const scalar alphaOnset_;

        //- Relative range for reducing swarm correction factor
        const scalar range_;

        //- Minimum swarm correction factor
        const scalar residualValue_;


public:

    //- Runtime type information
    TypeName("polynomialBlendout");


    // Constructors

        //- Construct from a dictionary and an interface
        polynomialBlendout
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~polynomialBlendout();


    // Member Functions

        //- Swarm correction coefficient
        virtual tmp<volScalarField> Cs() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace swarmCorrections
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
