/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     | Website:  https://openfoam.org
    \\  /    A nd           | Copyright (C) 2011-2022 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "dispersedVirtualMassModel.H"
#include "surfaceInterpolate.H"

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::virtualMassModels::dispersedVirtualMassModel::dispersedVirtualMassModel
(
    const dictionary& dict,
    const phaseInterface& interface,
    const bool registerObject
)
:
    virtualMassModel(dict, interface, registerObject),
    interface_(interface.modelCast<virtualMassModel, dispersedPhaseInterface>())
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::virtualMassModels::dispersedVirtualMassModel::~dispersedVirtualMassModel()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField>
Foam::virtualMassModels::dispersedVirtualMassModel::Ki() const
{
    return Cvm()*interface_.continuous().rho();
}


Foam::tmp<Foam::volScalarField>
Foam::virtualMassModels::dispersedVirtualMassModel::K() const
{
    return interface_.dispersed()*Ki();
}


Foam::tmp<Foam::surfaceScalarField>
Foam::virtualMassModels::dispersedVirtualMassModel::Kf() const
{
    return fvc::interpolate(interface_.dispersed())*fvc::interpolate(Ki());
}


// ************************************************************************* //
