/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "Shi.H"
#include "fvcCurl.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace wallLubricationModels
{
    defineTypeNameAndDebug(Shi, 0);
    addToRunTimeSelectionTable
    (
        wallLubricationModel,
        Shi,
        dictionary
    );
}
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::wallLubricationModels::Shi::Shi
(
    const dictionary& dict,
    const phaseInterface& interface
)
:
    dispersedWallLubricationModel(dict, interface),
    residualRe_
    (
        dimensionedScalar::lookupOrDefault("residualRe", dict, dimless, 1e-1)
    )
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::wallLubricationModels::Shi::~Shi()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

Foam::tmp<Foam::volVectorField> Foam::wallLubricationModels::Shi::
Fi() const
{
    const volVectorField& n(nWall());
    const volScalarField& y(yWall());
    tmp<volScalarField> td(interface_.dispersed().d());
    const volScalarField& d = td();

    const volScalarField Re(min(max(interface_.Re(), residualRe_), 100.0));
    const volScalarField Sr(min(interface_.Sr(Re), 1.0));
    const volScalarField Lu(Re*y/d);

    const volScalarField fReLR
    (
        1 + tanh(0.2*Re*sqr(y/d))*(0.37*Re - 0.12*sqrt(Re))
    );

    return zeroGradWalls
    (
        max
        (
            dimensionedScalar(inv(dimLength), Zero),
            exp
            (
               -0.22*pow(Sr/Re, 0.4)*pow(y/d*sqrt(Sr*Re), 2.5)
               *exp(-0.01*sqr(Re))
            )
           *fReLR*pow(2*y/(3*d), -2*tanh(0.01*Re))*0.84375/d
           *(
                neg0(Lu - 10)/(1 + 0.13*Lu*(0.53 + Lu))
              + pos(Lu - 10)*7.95*pow(Lu, -2.09)
            )
        )
       *interface_.continuous().rho()
       *magSqr(interface_.Ur() - (interface_.Ur() & n)*n)
       *n
    );
}


// ************************************************************************* //
