/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2020-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::RASModels::{Var}StabilisedRASModels

Description
    Add implicit and explicit coefficients to turbulence equations in case, the
    phase volume fraction vanishes.

\*---------------------------------------------------------------------------*/

#ifndef StabilisedRASModels_H
#define StabilisedRASModels_H

#include "phaseModel.H"
#include "fvc.H"
#include "fvm.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace RASModels
{

/*---------------------------------------------------------------------------*\
                    Class VarStabilisedRASModel Declaration
\*---------------------------------------------------------------------------*/

#define makeFieldStabilisedClass(Var, FieldType)                               \
    template<class BasicMomentumTransportModel>                                \
    class Var##StabilisedRASModel                                              \
    :                                                                          \
        public BasicMomentumTransportModel                                     \
    {                                                                          \
        const phaseModel& phase_;                                              \
                                                                               \
                                                                               \
    protected:                                                                 \
                                                                               \
        virtual tmp<fvMatrix<FieldType>> Var##Source() const                   \
        {                                                                      \
            tmp<fvMatrix<FieldType>> tfvm                                      \
            (                                                                  \
                BasicMomentumTransportModel::Var##Source()                     \
            );                                                                 \
                                                                               \
            tfvm.ref() +=                                                      \
                fvc::ddt(phase_.residualAlpha()*this->rho_, this->Var##_)      \
              - fvm::ddt(phase_.residualAlpha()*this->rho_, this->Var##_);     \
                                                                               \
            return tfvm;                                                       \
        }                                                                      \
                                                                               \
                                                                               \
    public:                                                                    \
                                                                               \
        typedef typename BasicMomentumTransportModel::alphaField               \
            alphaField;                                                        \
        typedef typename BasicMomentumTransportModel::rhoField                 \
            rhoField;                                                          \
                                                                               \
        TypeName("Var##StabilisedRASModel");                                   \
                                                                               \
                                                                               \
        Var##StabilisedRASModel                                                \
        (                                                                      \
            const alphaField& alpha,                                           \
            const rhoField& rho,                                               \
            const volVectorField& U,                                           \
            const surfaceScalarField& alphaRhoPhi,                             \
            const surfaceScalarField& phi,                                     \
            const viscosity& viscosity,                                   \
            const word& type = typeName                                        \
        )                                                                      \
        :                                                                      \
            BasicMomentumTransportModel                                        \
            (                                                                  \
                alpha,                                                         \
                rho,                                                           \
                U,                                                             \
                alphaRhoPhi,                                                   \
                phi,                                                           \
                viscosity,                                                     \
                type                                                           \
            ),                                                                 \
            phase_                                                             \
            (                                                                  \
                U.db().lookupObject<phaseModel>                                \
                (                                                              \
                    IOobject::groupName("alpha", alphaRhoPhi.group())          \
                )                                                              \
            )                                                                  \
        {                                                                      \
            if (type == typeName)                                              \
            {                                                                  \
                this->printCoeffs(type);                                       \
            }                                                                  \
        }                                                                      \
                                                                               \
        virtual ~Var##StabilisedRASModel()                                     \
        {}                                                                     \
    };

makeFieldStabilisedClass(k, scalar);
makeFieldStabilisedClass(epsilon, scalar);
makeFieldStabilisedClass(omega, scalar);
makeFieldStabilisedClass(R, symmTensor);


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace RASModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
