/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::wallBoilingModels::departureDiameterModels::ShinJonesDepartureDiameter

Description
    Shin & Jones (1993) correlation for bubble departure diameter.

    References:
    \verbatim
        Shin, T. S., & Jones, O. C. (1993).
        Nucleation and flashing in nozzles - 1: A distributed nucleation model.
        International Journal of Multiphase FLow, 19(6), 943-964.
    \endverbatim

SourceFiles
    ShinJonesDepartureDiameter.C

\*---------------------------------------------------------------------------*/

#ifndef ShinJonesDepartureDiameter_H
#define ShinJonesDepartureDiameter_H

#include "departureDiameterModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace wallBoilingModels
{
namespace departureDiameterModels
{

/*---------------------------------------------------------------------------*\
                 Class ShinJonesDepartureDiameter Declaration
\*---------------------------------------------------------------------------*/

class ShinJonesDepartureDiameter
:
    public departureDiameterModel
{
    // Private Data

        //- Optional phase name
        word phaseName_;

        //- User adjustable coefficient for departure diameter
        scalar K_;

        //- Minimum departure diameter
        scalar dMin_;


public:

    //- Runtime type information
    TypeName("ShinJones");


    // Constructors

        //- Construct from a dictionary
        ShinJonesDepartureDiameter(const dictionary& dict);

        //- Copy construct
        ShinJonesDepartureDiameter
        (
            const ShinJonesDepartureDiameter& model
        );

        //- Construct and return a clone
        virtual autoPtr<departureDiameterModel> clone() const
        {
            return autoPtr<departureDiameterModel>
            (
                new ShinJonesDepartureDiameter(*this)
            );
        }


    //- Destructor
    virtual ~ShinJonesDepartureDiameter();


    // Member Functions

        //- Calculate and return the departure diameter field
        virtual tmp<scalarField> dDeparture
        (
            const phaseModel& liquid,
            const phaseModel& vapor,
            const label patchi,
            const scalarField& Tl,
            const scalarField& Tsatw,
            const scalarField& L
        ) const;

        virtual void write(Ostream& os) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace departureDiameterModels
} // End namespace wallBoilingModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
