/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::wallBoilingModels::departureFrequencyModels::
    ShinJonesDepartureFrequency

Description
    Shin & Jones (1993) correlation for bubble departure frequency.

    References:
    \verbatim
        Shin, T. S., & Jones, O. C. (1993).
        Nucleation and flashing in nozzles - 1: A distributed nucleation model.
        International Journal of Multiphase FLow, 19(6), 943-964.
    \endverbatim

SourceFiles
    ShinJonesDepartureFrequency.C

\*---------------------------------------------------------------------------*/

#ifndef ShinJonesDepartureFrequency_H
#define ShinJonesDepartureFrequency_H

#include "departureFrequencyModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace wallBoilingModels
{
namespace departureFrequencyModels
{

/*---------------------------------------------------------------------------*\
                Class ShinJonesDepartureFrequency Declaration
\*---------------------------------------------------------------------------*/

class ShinJonesDepartureFrequency
:
    public departureFrequencyModel
{
    // Private Data:

        //- User adjustable coefficient for departure frequency
        scalar Cf_;


public:

    //- Runtime type information
    TypeName("ShinJones");


    // Constructors

        //- Construct from a dictionary
        ShinJonesDepartureFrequency(const dictionary& dict);

        //- Copy construct
        ShinJonesDepartureFrequency
        (
            const ShinJonesDepartureFrequency& model
        );

        //- Construct and return a clone
        virtual autoPtr<departureFrequencyModel> clone() const
        {
            return autoPtr<departureFrequencyModel>
            (
                new ShinJonesDepartureFrequency(*this)
            );
        }


    //- Destructor
    virtual ~ShinJonesDepartureFrequency();


    // Member Functions

        //- Calculate and return the bubble departure frequency
        virtual tmp<scalarField> fDeparture
        (
            const phaseModel& liquid,
            const phaseModel& vapor,
            const label patchi,
            const scalarField& Tl,
            const scalarField& Tsatw,
            const scalarField& L,
            const scalarField& dDep
        ) const;

        virtual void write(Ostream& os) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace departureFrequencyModels
} // End namespace wallBoilingModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
