/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     | Website:  https://openfoam.org
    \\  /    A nd           | Copyright (C) 2015-2022 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "phaseSystem.H"
#include "MomentumTransferPhaseSystem.H"
#include "OneResistanceHeatTransferPhaseSystem.H"
#include "TwoResistanceHeatTransferPhaseSystem.H"
#include "PhaseTransferPhaseSystem.H"
#include "InterfaceCompositionPhaseChangePhaseSystem.H"
#include "ThermalPhaseChangePhaseSystem.H"
#include "PopulationBalancePhaseSystem.H"
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
#include "InducedTurbulencePhaseSystem.H"
#include "TransitionPhaseSystem.H"
#include "ResolvedPhaseSystem.H"
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//

#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
    typedef
        PhaseTransferPhaseSystem
        <
            OneResistanceHeatTransferPhaseSystem
            <
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                InducedTurbulencePhaseSystem
                <
                    MomentumTransferPhaseSystem
                    <
                        ResolvedPhaseSystem<phaseSystem>
                    >
                >
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
            >
        >
        basicMultiphaseSystem;

    addNamedToRunTimeSelectionTable
    (
        phaseSystem,
        basicMultiphaseSystem,
        dictionary,
        basicMultiphaseSystem
    );

    typedef
        InterfaceCompositionPhaseChangePhaseSystem
        <
            PhaseTransferPhaseSystem
            <
                TwoResistanceHeatTransferPhaseSystem
                <
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                    InducedTurbulencePhaseSystem
                    <
                        MomentumTransferPhaseSystem
                        <
                            ResolvedPhaseSystem<phaseSystem>
                        >
                    >
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                >
            >
        >
        interfaceCompositionPhaseChangeMultiphaseSystem;

    addNamedToRunTimeSelectionTable
    (
        phaseSystem,
        interfaceCompositionPhaseChangeMultiphaseSystem,
        dictionary,
        interfaceCompositionPhaseChangeMultiphaseSystem
    );

    typedef
        ThermalPhaseChangePhaseSystem
        <
            PhaseTransferPhaseSystem
            <
                TwoResistanceHeatTransferPhaseSystem
                <
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                    InducedTurbulencePhaseSystem
                    <
                        MomentumTransferPhaseSystem
                        <
                            ResolvedPhaseSystem<phaseSystem>
                        >
                    >
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                >
            >
        >
        thermalPhaseChangeMultiphaseSystem;

    addNamedToRunTimeSelectionTable
    (
        phaseSystem,
        thermalPhaseChangeMultiphaseSystem,
        dictionary,
        thermalPhaseChangeMultiphaseSystem
    );

    typedef
        PopulationBalancePhaseSystem
        <
            PhaseTransferPhaseSystem
            <
                OneResistanceHeatTransferPhaseSystem
                <
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                    InducedTurbulencePhaseSystem
                    <
                        MomentumTransferPhaseSystem
                        <
                            ResolvedPhaseSystem<phaseSystem>
                        >
                    >
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                >
            >
        >
        populationBalanceMultiphaseSystem;

    addNamedToRunTimeSelectionTable
    (
        phaseSystem,
        populationBalanceMultiphaseSystem,
        dictionary,
        populationBalanceMultiphaseSystem
    );

    typedef
        InterfaceCompositionPhaseChangePhaseSystem
        <
            PopulationBalancePhaseSystem
            <
                PhaseTransferPhaseSystem
                <
                    TwoResistanceHeatTransferPhaseSystem
                    <
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                        InducedTurbulencePhaseSystem
                        <
                            MomentumTransferPhaseSystem
                            <
                                ResolvedPhaseSystem<phaseSystem>
                            >
                        >
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                    >
                >
            >
        >
        interfaceCompositionPhaseChangePopulationBalanceMultiphaseSystem;

    addNamedToRunTimeSelectionTable
    (
        phaseSystem,
        interfaceCompositionPhaseChangePopulationBalanceMultiphaseSystem,
        dictionary,
        interfaceCompositionPhaseChangePopulationBalanceMultiphaseSystem
    );

    typedef
        ThermalPhaseChangePhaseSystem
        <
            PopulationBalancePhaseSystem
            <
                PhaseTransferPhaseSystem
                <
                    TwoResistanceHeatTransferPhaseSystem
                    <
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                        InducedTurbulencePhaseSystem
                        <
                            MomentumTransferPhaseSystem
                            <
                                ResolvedPhaseSystem<phaseSystem>
                            >
                        >
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
                    >
                >
            >
        >
        thermalPhaseChangePopulationBalanceMultiphaseSystem;

    addNamedToRunTimeSelectionTable
    (
        phaseSystem,
        thermalPhaseChangePopulationBalanceMultiphaseSystem,
        dictionary,
        thermalPhaseChangePopulationBalanceMultiphaseSystem
    );

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
    typedef
        TransitionPhaseSystem
        <
            PopulationBalancePhaseSystem
            <
                PhaseTransferPhaseSystem
                <
                    OneResistanceHeatTransferPhaseSystem
                    <
                        InducedTurbulencePhaseSystem
                        <
                            MomentumTransferPhaseSystem
                            <
                                ResolvedPhaseSystem<phaseSystem>
                            >
                        >
                    >
                >
            >
        >
        populationBalanceTransitionMultiphaseSystem;

    addNamedToRunTimeSelectionTable
    (
        phaseSystem,
        populationBalanceTransitionMultiphaseSystem,
        dictionary,
        populationBalanceTransitionMultiphaseSystem
    );
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
}


// ************************************************************************* //
