/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2019-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "definitePhases.H"
#include "phaseSystem.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace blendingMethods
{
    defineTypeName(definitePhases);

    addToRunTimeSelectionTable
    (
        blendingMethod,
        definitePhases,
        dictionary
    );
}
}


// * * * * * * * * * * * * Protected Member Functions  * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField>
Foam::blendingMethods::definitePhases::fContinuous
(
    const UPtrList<const volScalarField>& alphas,
    const label phaseSet,
    const label systemSet
) const
{
    return
        alpha(alphas, phaseSet, false)
       /max(interface_.fluid().sumAlphaContinuous(), small);
}


Foam::tmp<Foam::volScalarField> Foam::blendingMethods::definitePhases::f
(
    const UPtrList<const volScalarField>& alphas,
    const label phaseSet,
    const label systemSet
) const
{
    label canBeContinuousPhaseSet = 0b00;
    label canBeContinuousSystemSet = 0b00;
    forAllConstIter(phaseInterface, interface_, iter)
    {
        if (canBeContinuous(iter.index()))
        {
            canBeContinuousPhaseSet += 0b01 << iter.index() & phaseSet;
            canBeContinuousSystemSet += 0b01 << iter.index() & systemSet;
        }
    }

    if (canBeContinuousPhaseSet == 0)
    {
        return constant(alphas, 0);
    }

    if (canBeContinuousPhaseSet == canBeContinuousSystemSet)
    {
        return
            fContinuous
            (
                alphas,
                canBeContinuousPhaseSet,
                canBeContinuousSystemSet
            );
    }

    return constant(alphas, 1);
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::blendingMethods::definitePhases::definitePhases
(
    const dictionary& dict,
    const phaseInterface& interface
)
:
    blendingMethod(dict, interface)
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::blendingMethods::definitePhases::~definitePhases()
{}


// * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * * //

bool
Foam::blendingMethods::definitePhases::canBeContinuous(const label index) const
{
    if (index == 0)
    {
        return interface_.phase1().continuous();
    }
    else
    {
        return interface_.phase2().continuous();
    }
}


bool Foam::blendingMethods::definitePhases::canSegregate() const
{
    return interface_.phase1().continuous() && interface_.phase2().continuous();
}


// ************************************************************************* //
