/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2018-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::interfaceCompressionModels::constantInterfaceCompression

Description
    Interface compression with a constant, user-specified coefficient.

SourceFiles
    constantInterfaceCompression.C

\*---------------------------------------------------------------------------*/

#ifndef constantInterfaceCompression_H
#define constantInterfaceCompression_H

#include "interfaceCompressionModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace interfaceCompressionModels
{

/*---------------------------------------------------------------------------*\
                Class constantInterfaceCompression Declaration
\*---------------------------------------------------------------------------*/

class constantInterfaceCompression
:
    public interfaceCompressionModel
{
    // Private Data

        //- Constant interface compression coefficient
        const dimensionedScalar C_;


public:

    //- Runtime type information
    TypeName("constantCoefficient");


    // Constructors

        //- Construct from a dictionary and a phase pair
        constantInterfaceCompression
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~constantInterfaceCompression();


    // Member Functions

        //- Interface compression coefficient
        virtual tmp<surfaceScalarField> C() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace interfaceCompressionModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
