/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2018-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::interfaceCompressionModel

Description
    Base class for modeling the interface compression flux which is
    added to the correction fluxes within multiphaseSystem::solveAlphas().

SourceFiles
    interfaceCompressionModel.C
    interfaceCompressionModelNew.C
    phaseSystem.C

\*---------------------------------------------------------------------------*/

#ifndef interfaceCompressionModel_H
#define interfaceCompressionModel_H

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#include "volFields.H"
#include "surfaceFields.H"
#include "dictionary.H"
#include "segregatedPhaseInterface.H"
#include "runTimeSelectionTables.H"

namespace Foam
{

class phaseInterface;
class phaseModel;

/*---------------------------------------------------------------------------*\
                  Class interfaceCompressionModel Declaration
\*---------------------------------------------------------------------------*/

class interfaceCompressionModel
{
    // Private Data

        //- Phase interface
        const segregatedPhaseInterface interface_;


protected:

    // Protected Data

        //- Reference to the mesh
        const fvMesh& mesh_;


public:

    //- Runtime type information
    TypeName("interfaceCompressionModel");


    // Declare runtime construction

        declareRunTimeSelectionTable
        (
            autoPtr,
            interfaceCompressionModel,
            dictionary,
            (
                const dictionary& dict,
                const phaseInterface& interface
            ),
            (dict, interface)
        );


    // Static Data Members

        //- Does this model require correcting on fixed flux boundaries?
        static const bool correctFixedFluxBCs = true;


    // Constructors

        //- Construct from a dictionary and an interface
        interfaceCompressionModel
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~interfaceCompressionModel();


    // Selectors

        static autoPtr<interfaceCompressionModel> New
        (
            const dictionary& dict,
            const phaseInterface& interface,
            const bool outer=true
        );


    // Member Functions

        //- Interface compression coefficient
        virtual tmp<surfaceScalarField> C() const = 0;

        //- Interface compression flux
        virtual tmp<surfaceScalarField> phirc(const phaseModel& phase) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
