/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::surfaceTensionForceModels::continuumSurfaceForce

Description
    Continuum surface force approach according to Brackbill et al. (1992)

    Reference:
    \verbatim
        Brackbill, J. U., Kothe, D. B., Zemach, C. (1992).
        A continuum method for modeling surface tension.
        Journal of Computational Physics, 100, 335-354.
    \endverbatim

SourceFiles
    continuumSurfaceForce.C

\*---------------------------------------------------------------------------*/

#ifndef continuumSurfaceForce_H
#define continuumSurfaceForce_H

#include "surfaceTensionForceModel.H"
#include "surfaceFields.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace surfaceTensionForceModels
{

/*---------------------------------------------------------------------------*\
                    Class continuumSurfaceForce Declaration
\*---------------------------------------------------------------------------*/

class continuumSurfaceForce
:
    public surfaceTensionForceModel
{
public:

    //- Runtime type information
    TypeName("continuumSurfaceForce");


    // Constructors

        //- Construct from phaseSystem
        continuumSurfaceForce(const phaseSystem& fluid);


    //- Destructor
    virtual ~continuumSurfaceForce();


    // Member Functions

        //- Return the curvature of this interface
        virtual tmp<volScalarField> K
        (
            const segregatedPhaseInterface& interface
        ) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace surfaceTensionForceModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
