/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2020-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::surfaceTensionForceModel

Description
    Base class for modeling the surface tension force flux.

SourceFiles
    surfaceTensionForceModel.C
    surfaceTensionForceModelNew.C
    phaseSystem.C

\*---------------------------------------------------------------------------*/

#ifndef surfaceTensionForceModel_H
#define surfaceTensionForceModel_H

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#include "volFields.H"
#include "dictionary.H"
#include "segregatedPhaseInterface.H"
#include "runTimeSelectionTables.H"
#include "phaseSystem.H"

namespace Foam
{

class phaseModel;

/*---------------------------------------------------------------------------*\
                  Class surfaceTensionForceModel Declaration
\*---------------------------------------------------------------------------*/

class surfaceTensionForceModel
{
protected:

    // Protected Data

        //- Reference to the mesh
        const phaseSystem& fluid_;


public:

    //- Runtime type information
    TypeName("surfaceTensionForceModel");


    // Declare runtime construction

        declareRunTimeSelectionTable
        (
            autoPtr,
            surfaceTensionForceModel,
            dictionary,
            (
                const phaseSystem& fluid
            ),
            (fluid)
        );


    // Constructors

        //- Construct from phaseSystem
        surfaceTensionForceModel(const phaseSystem& fluid);


    //- Destructor
    virtual ~surfaceTensionForceModel();


    // Selectors

        static autoPtr<surfaceTensionForceModel> New(const phaseSystem& fluid);


    // Member Functions

        //- Return the curvature of this interface
        virtual tmp<volScalarField> K
        (
            const segregatedPhaseInterface& interface
        ) const = 0;

        //- Surface tension force flux
        virtual tmp<surfaceScalarField> surfaceTensionForcef
        (
            const segregatedPhaseInterface& interface
        ) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
