/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2020-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "continuumSurfaceForce.H"

// * * * * * * * * * * * * * * * * Selector  * * * * * * * * * * * * * * * * //

Foam::autoPtr<Foam::surfaceTensionForceModel>
Foam::surfaceTensionForceModel::New
(
    const phaseSystem& fluid
)
{
    // Select the base method if method information is missing.
    const word methodDictName = Foam::surfaceTensionForceModel::typeName;
    const word typeKeyword = "type";
    word selectedType;

    if (fluid.found(methodDictName))
    {
        const dictionary& methodDict = fluid.subDict(methodDictName);

        if (methodDict.found(typeKeyword))
        {
            selectedType = methodDict.lookup<word>(typeKeyword);
            Info<< "Selecting surfaceTensionForceModel: "
                << selectedType<< endl;

            dictionaryConstructorTable::iterator cstrIter =
                dictionaryConstructorTablePtr_->find(selectedType);

            if (cstrIter == dictionaryConstructorTablePtr_->end())
            {
                FatalErrorInFunction
                    << "Unknown " << methodDictName << " type "
                    << selectedType << endl << endl
                    << "Valid " << methodDictName << " types are : " << endl
                    << dictionaryConstructorTablePtr_->sortedToc() << endl
                    << exit(FatalError);
            }

            return cstrIter()(fluid);
        }
    }

    Info<< "Selecting surfaceTensionForceModel: continuumSurfaceForce" << endl;

    return
        autoPtr<surfaceTensionForceModel>
        (
            new surfaceTensionForceModels::continuumSurfaceForce(fluid)
        );
}


// ************************************************************************* //
