/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::shearAndCurvatureUnderResolution

Description
    The under-resolution indicator function \f$f_\mathrm{UR}\f$ is calculated as
    a combination of shear and curvature under-resolution:

    \f[
        f_\mathrm{UR} =
            \mathit{max}
            \left(f_\mathrm{UR}^\mathrm{shear},
                  f_\mathrm{UR}^\mathrm{curvature}\right).
    \f]

    Similarly to the curvature under-resolution model, a method for the
    calculation of grid size has to be selected.

Usage
    \table
        Property | Description                     | Required  | Default value
        delta    | method for estimating cell size | yes       | none
    \endtable

See also
    Foam::underResolutionModels::shearUnderResolution
    Foam::underResolutionModels::curvatureUnderResolution
    Foam::ResolvedPhaseSystem

SourceFiles
    shearAndCurvatureUnderResolution.C

\*---------------------------------------------------------------------------*/

#ifndef shearAndCurvatureUnderResolution_H
#define shearAndCurvatureUnderResolution_H

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#include "underResolutionModel.H"
#include "shearUnderResolution.H"
#include "curvatureUnderResolution.H"

namespace Foam
{
namespace underResolutionModels
{

/*---------------------------------------------------------------------------*\
                    Class shearAndCurvatureUnderResolution Declaration
\*---------------------------------------------------------------------------*/

class shearAndCurvatureUnderResolution
:
    public underResolutionModel
{
    // Private Data

        //- Shear under resolution model
        shearUnderResolution shearUnderResolution_;

        //- Curvature under resolution model
        curvatureUnderResolution curvatureUnderResolution_;


public:

    //- Runtime type information
    TypeName("shearAndCurvature");


    // Constructors

        //- Construct from a dictionary and an interface
        shearAndCurvatureUnderResolution
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~shearAndCurvatureUnderResolution();


    // Member Functions

        virtual void correct();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace underResolutionModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
