/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2018-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::clusteringByContinuityEqnModel

Description
    Baseclass for modeling the formation of a resolved structure from a smeared
    phase fraction field by an additional flux in the phase transport equations,
    the clustering flux.

See also
    Foam::multiphaseSystem
    Foam::TransitionPhaseSystem

SourceFiles
    clusteringByContinuityEqnModel.C
    clusteringByContinuityEqnModelNew.C

\*---------------------------------------------------------------------------*/

#ifndef clusteringByContinuityEqnModel_H
#define clusteringByContinuityEqnModel_H

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#include "volFields.H"
#include "dictionary.H"
#include "phaseInterface.H"
#include "runTimeSelectionTables.H"

namespace Foam
{

class phaseSystem;
class phaseModel;

/*---------------------------------------------------------------------------*\
               Class clusteringByContinuityEqnModel Declaration
\*---------------------------------------------------------------------------*/

class clusteringByContinuityEqnModel
{
    // Private Data

        //- Continuous phase
        const phaseModel& continuousPhase_;


protected:

    // Protected Data

        //- Reference to the mesh
        const fvMesh& mesh_;


public:

    //- Runtime type information
    TypeName("clusteringByContinuityEqnModel");


    // Declare runtime construction

        declareRunTimeSelectionTable
        (
            autoPtr,
            clusteringByContinuityEqnModel,
            dictionary,
            (
                const dictionary& dict,
                const phaseInterface& interface
            ),
            (dict, interface)
        );


    // Static Data Members

        //- Does this model require correcting on fixed flux boundaries?
        static const bool correctFixedFluxBCs = true;


    // Constructors

        //- Construct from a dictionary and an interface
        clusteringByContinuityEqnModel
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~clusteringByContinuityEqnModel();


    // Selectors

        static autoPtr<clusteringByContinuityEqnModel> New
        (
            const dictionary& dict,
            const phaseInterface& interface,
            const bool outer=true
        );


    // Member Functions

        //- Coefficient within expression of flux for formation of resolved
        //  structures
        virtual tmp<surfaceScalarField> C() const = 0;

        //- Flux for formation of resolved structures
        virtual tmp<surfaceScalarField> phirc(const phaseModel& phase) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
