/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2018-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::clusteringByContinuityEqnModels::constantClusteringByContinuityEqn

Description
    Constant coefficient clustering model.

SourceFiles
    constantClusteringByContinuityEqn.C

\*---------------------------------------------------------------------------*/

#ifndef constantClusteringByContinuityEqn_H
#define constantClusteringByContinuityEqn_H

#include "clusteringByContinuityEqnModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace clusteringByContinuityEqnModels
{

/*---------------------------------------------------------------------------*\
              Class constantClusteringByContinuityEqn Declaration
\*---------------------------------------------------------------------------*/

class constantClusteringByContinuityEqn
:
    public clusteringByContinuityEqnModel
{
    // Private Data

        //- Constant coefficient
        const dimensionedScalar C_;


public:

    //- Runtime type information
    TypeName("constant");


    // Constructors

        //- Construct from a dictionary and an interface
        constantClusteringByContinuityEqn
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~constantClusteringByContinuityEqn();


    // Member Functions

        //- Coefficient within expression of flux for formation of resolved
        //  structures
        virtual tmp<surfaceScalarField> C() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace clusteringByContinuityEqnModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
