/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     | Website:  https://openfoam.org
    \\  /    A nd           | Copyright (C) 2021-2022 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "segregatedPhaseInterface.H"
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
#include "phaseSystem.H"
#include "fvcGrad.H"
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
    bool segregatedPhaseInterfaceAddedHeadSeparator =
        phaseInterface::addHeadSeparator(segregatedPhaseInterface::separator());

    bool segregatedPhaseInterfaceAddedOldSeparatorToSeparator =
        phaseInterface::addOldSeparatorToSeparator
        (
            "and",
            segregatedPhaseInterface::separator()
        );
}

namespace Foam
{
    defineTypeNameAndDebugWithName
    (
        segregatedPhaseInterface,
        separatorsToTypeName({separator()}).c_str(),
        0
    );
    addToRunTimeSelectionTable(phaseInterface, segregatedPhaseInterface, word);
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::segregatedPhaseInterface::segregatedPhaseInterface
(
    const phaseModel& phase1,
    const phaseModel& phase2
)
:
    phaseInterface(phase1, phase2)
{}


Foam::segregatedPhaseInterface::segregatedPhaseInterface
(
    const phaseSystem& fluid,
    const word& name
)
:
    phaseInterface(fluid, name)
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::segregatedPhaseInterface::~segregatedPhaseInterface()
{}


// * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * * //

Foam::word Foam::segregatedPhaseInterface::name() const
{
    return phase1().name() + '_' + separator() + '_' + phase2().name();
}


//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
Foam::tmp<Foam::volScalarField>
Foam::segregatedPhaseInterface::Ai() const
{
    const volScalarField gradPhase1(mag(fvc::grad(phase1())));
    const volScalarField gradPhase2(mag(fvc::grad(phase2())));

    return
        2.0*gradPhase1*gradPhase2/(gradPhase1 + gradPhase2 + fluid().deltaN());
}


Foam::tmp<Foam::volVectorField>
Foam::segregatedPhaseInterface::gradAlpha() const
{
    return fluid().gradAlpha(phase1(), phase2());
}


Foam::tmp<Foam::surfaceVectorField>
Foam::segregatedPhaseInterface::gradAlphafv() const
{
    return fluid().gradAlphafv(phase1(), phase2());
}


Foam::tmp<Foam::surfaceScalarField>
Foam::segregatedPhaseInterface::gradAlphaf() const
{
    return fluid().gradAlphaf(phase1(), phase2());
}


Foam::tmp<Foam::volVectorField>
Foam::segregatedPhaseInterface::nHat() const
{
    return fluid().nHat(phase1(), phase2());
}


Foam::tmp<Foam::surfaceVectorField>
Foam::segregatedPhaseInterface::nHatfv() const
{
    return fluid().nHatfv(phase1(), phase2());
}


Foam::tmp<Foam::surfaceScalarField>
Foam::segregatedPhaseInterface::nHatf() const
{
    return fluid().nHatf(phase1(), phase2());
}


Foam::tmp<Foam::volVectorField> Foam::segregatedPhaseInterface::UrI() const
{
    const phaseInterfaceKey key(phase1(), phase2());

    return fluid().UrI(key);
}


Foam::tmp<Foam::volScalarField>
Foam::segregatedPhaseInterface::underResolution() const
{
    const phaseInterfaceKey key(phase1(), phase2());

    return fluid().underResolution(key);
}


Foam::tmp<Foam::volScalarField> Foam::segregatedPhaseInterface::K() const
{
    const phaseInterfaceKey key(phase1(), phase2());

    return fluid().K(key);
}
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//


// ************************************************************************* //
