/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::diameterModels::cudaUtilities::CUDAPopulationBalance

Description
    Collection of fields required for kernel computations.

SourceFiles
    CUDAPopulationBalance.C

\*---------------------------------------------------------------------------*/

#ifndef CUDAPopulationBalance_H
#define CUDAPopulationBalance_H

#include "OFMemoryManagedField.H"

#ifndef __CUDACC__
#define __host__
#define __device__
#endif

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diameterModels
{
namespace cudaUtilities
{

/*---------------------------------------------------------------------------*\
                    Class CUDAPopulationBalance Declaration
\*---------------------------------------------------------------------------*/

class CUDAPopulationBalance
{

// Private Data
    OFMemoryManagedField alphas_;

    OFMemoryManagedField continuousTurbulenceEpsilon_;

    OFMemoryManagedField sizeGroupsdSph_;

    OFMemoryManagedField sizeGroupsX_;

    OFMemoryManagedField continuousPhaseRho_;

    OFMemoryManagedField sigmaWithContinuousPhaseI_;

    OFMemoryManagedField UxPhaseI_;

    OFMemoryManagedField UyPhaseI_;

    OFMemoryManagedField UzPhaseI_;

    OFMemoryManagedField residualAlphaPhaseI_;

    OFMemoryManagedField continuousPhaseThermoMu_;

public:
    OFMemoryManagedField
    setAlphas(unsigned int domainSize);

    __device__ __host__
    OFMemoryManagedField alphas()
    { return this->alphas_; }

    OFMemoryManagedField
    setContinuousTurbulenceEpsilon(unsigned int domainSize);

    __device__ __host__
    OFMemoryManagedField continuousTurbulenceEpsilon()
    { return this-> continuousTurbulenceEpsilon_; }

    OFMemoryManagedField
    setSizeGroupsdSph(unsigned int numberOfGroups);

    __device__ __host__
    OFMemoryManagedField sizeGroupsdSph()
    { return this-> sizeGroupsdSph_; }

    OFMemoryManagedField
    setSizeGroupsX(unsigned int numberOfGroups);

    __device__ __host__
    OFMemoryManagedField sizeGroupsX()
    { return this-> sizeGroupsX_; }

    OFMemoryManagedField
    setContinuousPhaseRho(unsigned int domainSize);

    __device__ __host__
    OFMemoryManagedField continuousPhaseRho()
    { return this-> continuousPhaseRho_; }

    OFMemoryManagedField
    setSigmaWithContinuousPhaseI
    (
        unsigned int numberOfGroups,
        unsigned int domainSize
    );

    __device__ __host__
    OFMemoryManagedField sigmaWithContinuousPhaseI()
    { return this-> sigmaWithContinuousPhaseI_; }

    OFMemoryManagedField
    setUxPhaseI(unsigned int numberOfGroups, unsigned int domainSize);

    __device__ __host__
    OFMemoryManagedField UxPhaseI()
    { return this-> UxPhaseI_; }

    OFMemoryManagedField
    setUyPhaseI(unsigned int numberOfGroups, unsigned int domainSize);

    __device__ __host__
    OFMemoryManagedField UyPhaseI()
    { return this-> UyPhaseI_; }

    OFMemoryManagedField
    setUzPhaseI(unsigned int numberOfGroups, unsigned int domainSize);

    __device__ __host__
    OFMemoryManagedField UzPhaseI()
    { return this-> UzPhaseI_; }

    OFMemoryManagedField
    setResidualAlphaPhaseI(unsigned int numberOfGroups);

    __device__ __host__
    OFMemoryManagedField residualAlphaPhaseI()
    { return this-> residualAlphaPhaseI_; }

    OFMemoryManagedField
    setContinuousPhaseThermoMu(unsigned int domainSize);

    __device__ __host__
    OFMemoryManagedField continuousPhaseThermoMu()
    { return this-> continuousPhaseThermoMu_; }

    CUDAPopulationBalance();
};

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace cudaUtilities
} // End namespace diameterModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
