/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::diameterModels::cudaUtilities::OFMemoryManagedField

Description
    Object that has access to CUDA array and writes OpenFOAM data to this array.

SourceFiles
    OFMemoryManagedField.C

\*---------------------------------------------------------------------------*/

#ifndef OFMemoryManagedField_H
#define OFMemoryManagedField_H

#ifndef __CUDACC__
#define __host__
#define __device__
#endif

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diameterModels
{
namespace cudaUtilities
{

/*---------------------------------------------------------------------------*\
                     Class OFMemoryManagedField Declaration
\*---------------------------------------------------------------------------*/

class OFMemoryManagedField
{
    // Private Data

        //- Field pointer
        double* fieldPtr_ = nullptr;
        std::size_t size_ = 0;

public:

    // Constructor
        OFMemoryManagedField();

        OFMemoryManagedField(std::size_t size);

        OFMemoryManagedField(double* fieldPtr, std::size_t size);

    // Member Functions
        //- Get field pointer
        __device__ __host__
        double* fieldPtr() const { return fieldPtr_; }

        //- Get field size
        __device__ __host__
        std::size_t size() const { return size_; }

        //- Get/set value in the array
        __device__ __host__
        double & operator [](int i) const { return fieldPtr_[i]; }

        //- Resize the field
        void resize(std::size_t size);


};

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace cudaUtilities
} // End namespace diameterModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
