/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf
    and some other institution

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "CUDALehrMilliesMewesSupportModel.H"
#include "OFMemoryManagedField.H"
#include <iostream>
#include "CUDAModelRunner.H"
#include <vector>
#include <assert.h>


using namespace std;
using namespace Foam::diameterModels::cudaUtilities;

// * * * * * * * * * * * * * * * * * * PIMPL * * * * * * * * * * * * * * * * //


struct Foam::diameterModels::binaryBreakupModels::CUDALehrMilliesMewesSupportModel::
CUDALehrMilliesMewesBinaryBreakupModelPimpl
{
    double SMALL_;

    __device__ void computeRate(CUDAPopulationBalance popBal, double* resultField, int i, int j, int index, int domainSize) const
    {
        double L =
            (
                pow
                (
                    popBal.sigmaWithContinuousPhaseI()[j*domainSize+index]
                   /popBal.continuousPhaseRho()[index],
                    0.6
                )
               /pow(popBal.continuousTurbulenceEpsilon()[index], 0.4)
            );

        double T =
            (
                pow
                (
                    popBal.sigmaWithContinuousPhaseI()[j*domainSize+index]
                   /popBal.continuousPhaseRho()[index],
                    0.4
                )
               /pow(popBal.continuousTurbulenceEpsilon()[index], 0.6)
            );

        resultField[index] =
            0.5*pow(popBal.sizeGroupsdSph()[j]/L, 5.0/3.0)
           *exp(-sqrt(2.0)/pow(popBal.sizeGroupsdSph()[j]/L, 3))
           *6/pow(3.141592654f, 1.5)/pow(popBal.sizeGroupsdSph()[i]/L, 3)
           *exp(-2.25*pow(log(pow(2.0, 0.4)*popBal.sizeGroupsdSph()[i]/L), 2))
           /max
                (
                    1 + erf(1.5*log(pow(2.0, 1.0/15.0)*popBal.sizeGroupsdSph()[j]/L)),
                    SMALL_
                )
           /(T*pow(L, 3.0));
    }
};


class
Foam::diameterModels::binaryBreakupModels::CUDALehrMilliesMewesSupportModel::
CUDALehrMilliesMewesBinaryBreakupRunnerPimpl
 : public CUDAModelRunner<CUDALehrMilliesMewesBinaryBreakupModelPimpl>
{
public:
    CUDALehrMilliesMewesBinaryBreakupRunnerPimpl(int numStreams, CUDALehrMilliesMewesBinaryBreakupModelPimpl model)
     : CUDAModelRunner<CUDALehrMilliesMewesBinaryBreakupModelPimpl>(numStreams, model)
    {}
};

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::diameterModels::binaryBreakupModels::CUDALehrMilliesMewesSupportModel::
CUDALehrMilliesMewesSupportModel(int numStreams)
  : pimpl(new CUDALehrMilliesMewesBinaryBreakupRunnerPimpl(numStreams, CUDALehrMilliesMewesBinaryBreakupModelPimpl()))
{}

// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::diameterModels::binaryBreakupModels::CUDALehrMilliesMewesSupportModel::
~CUDALehrMilliesMewesSupportModel() = default;

// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

void
Foam::diameterModels::binaryBreakupModels::CUDALehrMilliesMewesSupportModel::
calculateBinaryBreakupRate
(
    CUDAPopulationBalance popBal,
    int domainSize,
    std::vector<std::pair<int, int>> &pairs
)
{
    pimpl->calculateRate
    (
        popBal,
        domainSize,
        pairs
    );
}

void
Foam::diameterModels::binaryBreakupModels::CUDALehrMilliesMewesSupportModel::
setModelVariables
(
    double SMALL
)
{
    pimpl->model_.SMALL_ = SMALL;
}


OFMemoryManagedField
Foam::diameterModels::binaryBreakupModels::CUDALehrMilliesMewesSupportModel::
getBinaryBreakupRate
(
    int i,
    int j
)
{
    return pimpl->getRate
    (
        i,
        j
    );
}


// ************************************************************************* //
