/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf
    and some other institution

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "CUDACoulaloglouTavlaridesSupportModel.H"
#include "OFMemoryManagedField.H"
#include <iostream>
#include "CUDAModelRunner.H"
#include <vector>
#include <assert.h>

using namespace std;
using namespace Foam::diameterModels::cudaUtilities;

// * * * * * * * * * * * * * * * * * * PIMPL * * * * * * * * * * * * * * * * //


__device__ double pow3(double x)
{
    return pow(x, 3);
}


__device__ double pow4(double x)
{
    return pow(x, 4);
}


__device__ double sqr_cou(double x)
{
    return pow(x, 2);
}


struct Foam::diameterModels::coalescenceModels::CUDACoulaloglouTavlaridesSupportModel::
CUDACoulaloglouTavlaridesModelPimpl
{
    double C1_;
    double C2_;

    __device__ void computeRate(CUDAPopulationBalance popBal, double* resultField, int i, int j, int index, int domainSize) const
    {
        resultField[index] = 0.0;

        resultField[index] +=
            C1_*(pow(popBal.sizeGroupsX()[i], 2.0/3.0) + pow(popBal.sizeGroupsX()[j], 2.0/3.0))
           *sqrt(pow(popBal.sizeGroupsX()[i], 2.0/9.0) + pow(popBal.sizeGroupsX()[j], 2.0/9.0))
           *cbrt(popBal.continuousTurbulenceEpsilon()[index])/(1 + popBal.alphas()[index])
           *exp
            (
              - C2_*popBal.continuousPhaseThermoMu()[index]*popBal.continuousPhaseRho()[index]
               *popBal.continuousTurbulenceEpsilon()[index]
               /sqr_cou(popBal.sigmaWithContinuousPhaseI()[i*domainSize+index])
               /pow3(1 + popBal.alphas()[index])
               *pow4(cbrt(popBal.sizeGroupsX()[i])*cbrt(popBal.sizeGroupsX()[j])/(cbrt(popBal.sizeGroupsX()[i]) + cbrt(popBal.sizeGroupsX()[j])))
            );
    }
};

class
Foam::diameterModels::coalescenceModels::CUDACoulaloglouTavlaridesSupportModel::
CUDACoulaloglouTavlaridesRunnerPimpl
: public CUDAModelRunner<CUDACoulaloglouTavlaridesModelPimpl>
{
public:
    CUDACoulaloglouTavlaridesRunnerPimpl(int numStreams, CUDACoulaloglouTavlaridesModelPimpl model)
     : CUDAModelRunner<CUDACoulaloglouTavlaridesModelPimpl>(numStreams, model)
    {}
};

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::diameterModels::coalescenceModels::CUDACoulaloglouTavlaridesSupportModel::
CUDACoulaloglouTavlaridesSupportModel(int numStreams)
  : pimpl(new CUDACoulaloglouTavlaridesRunnerPimpl(numStreams, CUDACoulaloglouTavlaridesModelPimpl()))
{}

// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::diameterModels::coalescenceModels::CUDACoulaloglouTavlaridesSupportModel::
~CUDACoulaloglouTavlaridesSupportModel() = default;

// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

void
Foam::diameterModels::coalescenceModels::CUDACoulaloglouTavlaridesSupportModel::
calculateCoalescenceRate
(
    CUDAPopulationBalance popBal,
    int domainSize,
    const std::vector<std::pair<int, int>> &pairs
)
{
    pimpl->calculateRate
    (
        popBal,
        domainSize,
        pairs
    );
}

void
Foam::diameterModels::coalescenceModels::CUDACoulaloglouTavlaridesSupportModel::
setModelVariables
(
    double C1,
    double C2
)
{
    pimpl->model_.C1_ = C1;
    pimpl->model_.C2_ = C2;
}


OFMemoryManagedField
Foam::diameterModels::coalescenceModels::CUDACoulaloglouTavlaridesSupportModel::
getCoalescenceRate
(
    int i,
    int j
)
{
    return pimpl->getRate
    (
        i,
        j
    );
}

// ************************************************************************* //
