/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::diameterModels::coalescenceModels::CUDALehrMilliesMewes

Description
    CUDA interface for the CUDALehrMilliesMewes coalescence model.

SourceFiles
    CUDALehrMilliesMewesCoalescenceSupportModel.C

\*---------------------------------------------------------------------------*/


#ifndef CUDALehrMilliesMewesCoalescenceSupportModel_H
#define CUDALehrMilliesMewesCoalescenceSupportModel_H

#include <memory>
#include <vector>
#include "CUDAPopulationBalance.H"

using namespace std;

using namespace Foam::diameterModels::cudaUtilities;

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diameterModels
{
namespace coalescenceModels
{

/*---------------------------------------------------------------------------*\
         Class CUDALehrMilliesMewesCoalescenceSupportModel Declaration
\*---------------------------------------------------------------------------*/


class CUDALehrMilliesMewesCoalescenceSupportModel
{
public:
    // Public forward declarations
    class CUDALehrMilliesMewesCoalescenceRunnerPimpl;

    struct CUDALehrMilliesMewesCoalescenceModelPimpl;

    // Constructor
    CUDALehrMilliesMewesCoalescenceSupportModel(int numStreams);

    //- Destructor
    ~CUDALehrMilliesMewesCoalescenceSupportModel();

    // Member Functions

        //- Calculate coalescence rate
        void calculateCoalescenceRate
        (
            CUDAPopulationBalance popBal,
            int domainSize,
            const std::vector<std::pair<int, int>> &pairs
        );

        //- Set values required by the model
        void setModelVariables
        (
            double uCrit,
            double alphaMax
        );

        //- Get a field with results
        OFMemoryManagedField getCoalescenceRate
        (
            int i,
            int j
        );

private:
        //- Pimpl pattern implementation
        std::unique_ptr<CUDALehrMilliesMewesCoalescenceRunnerPimpl> pimpl;

};

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace coalescenceModels
} // End namespace diameterModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
