/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf
    and some other institution

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "CUDALehrMilliesMewesCoalescenceSupportModel.H"
#include "OFMemoryManagedField.H"
#include <iostream>
#include "CUDAModelRunner.H"
#include <vector>
#include <assert.h>

using namespace std;
using namespace Foam::diameterModels::cudaUtilities;

// * * * * * * * * * * * * * * * * * * PIMPL * * * * * * * * * * * * * * * * //

struct Foam::diameterModels::coalescenceModels::CUDALehrMilliesMewesCoalescenceSupportModel::
CUDALehrMilliesMewesCoalescenceModelPimpl
{
    double uCrit_;
    double alphaMax_;

    __device__ void computeRate(CUDAPopulationBalance popBal, double* resultField, int i, int j, int index, int domainSize) const
    {
        double dUx = popBal.UxPhaseI()[i*domainSize+index]-popBal.UxPhaseI()[j*domainSize+index];
        double dUy = popBal.UyPhaseI()[i*domainSize+index]-popBal.UyPhaseI()[j*domainSize+index];
        double dUz = popBal.UzPhaseI()[i*domainSize+index]-popBal.UzPhaseI()[j*domainSize+index];


        double mag_ = sqrt(pow(dUx, 2) + pow(dUy, 2) + pow(dUz, 2));

        double uChar =
        (
            max
            (
                sqrt(2.0)
               *cbrt(popBal.continuousTurbulenceEpsilon()[index])
               *sqrt
                (
                    cbrt(pow(popBal.sizeGroupsdSph()[i], 2)) +
                    cbrt(pow(popBal.sizeGroupsdSph()[j], 2))
                ),
                mag_
            )
        );

        resultField[index] =
            3.141592654f/4
           *pow(popBal.sizeGroupsdSph()[i] + popBal.sizeGroupsdSph()[j], 2)
           *min(uChar, uCrit_)
           *exp
            (
            -pow
                (
                    cbrt(alphaMax_)
                /cbrt
                    (
                        max(popBal.alphas()[index],
                        popBal.residualAlphaPhaseI()[i])
                    ) - 1,
                    2
                )
            );
    }
};

class
Foam::diameterModels::coalescenceModels::CUDALehrMilliesMewesCoalescenceSupportModel::
CUDALehrMilliesMewesCoalescenceRunnerPimpl
: public CUDAModelRunner<CUDALehrMilliesMewesCoalescenceModelPimpl>
{
public:
    CUDALehrMilliesMewesCoalescenceRunnerPimpl(int numStreams, CUDALehrMilliesMewesCoalescenceModelPimpl model)
     : CUDAModelRunner<CUDALehrMilliesMewesCoalescenceModelPimpl>(numStreams, model)
    {}
};

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::diameterModels::coalescenceModels::CUDALehrMilliesMewesCoalescenceSupportModel::
CUDALehrMilliesMewesCoalescenceSupportModel(int numStreams)
  : pimpl(new CUDALehrMilliesMewesCoalescenceRunnerPimpl(numStreams, CUDALehrMilliesMewesCoalescenceModelPimpl()))
{}

// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::diameterModels::coalescenceModels::CUDALehrMilliesMewesCoalescenceSupportModel::
~CUDALehrMilliesMewesCoalescenceSupportModel() = default;

// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

void
Foam::diameterModels::coalescenceModels::CUDALehrMilliesMewesCoalescenceSupportModel::
calculateCoalescenceRate
(
    CUDAPopulationBalance popBal,
    int domainSize,
    const std::vector<std::pair<int, int>> &pairs
)
{
    pimpl->calculateRate
    (
        popBal,
        domainSize,
        pairs
    );
}

void
Foam::diameterModels::coalescenceModels::CUDALehrMilliesMewesCoalescenceSupportModel::
setModelVariables
(
    double uCrit,
    double alphaMax
)
{
    pimpl->model_.uCrit_ = uCrit;
    pimpl->model_.alphaMax_ = alphaMax;
}


OFMemoryManagedField
Foam::diameterModels::coalescenceModels::CUDALehrMilliesMewesCoalescenceSupportModel::
getCoalescenceRate
(
    int i,
    int j
)
{
    return pimpl->getRate
    (
        i,
        j
    );
}

// ************************************************************************* //
