/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2019-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::diameterModels::nucleationModels::phaseTransferEntrainmentModel

Description
    Abstract base class for phaseTransferEntrainmentModels. Those models read
    the entrainment rate computed in the phaseTransfer framework and add it to
    the dispersed phase number density equation.

SourceFiles
    phaseTransferEntrainmentModel.C

\*---------------------------------------------------------------------------*/

#ifndef phaseTransferEntrainmentModel_H
#define phaseTransferEntrainmentModel_H

#include "nucleationModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diameterModels
{
namespace nucleationModels
{

/*---------------------------------------------------------------------------*\
                Class phaseTransferEntrainmentModel Declaration
\*---------------------------------------------------------------------------*/

class phaseTransferEntrainmentModel
:
    public nucleationModel
{
    // Private Data

        //- Interfaces in which entrainment occurs
        PtrList<phaseInterface> interfaces_;


    // Private Member Functions

        //- Scale according to distribution
        virtual dimensionedScalar distribution(const label i) = 0;


public:

    //- Runtime type information
    TypeName("phaseTransferEntrainmentModel");


    // Constructor

        phaseTransferEntrainmentModel
        (
            const populationBalanceModel& popBal,
            const dictionary& dict
        );


    //- Destructor
    virtual ~phaseTransferEntrainmentModel()
    {}


    // Member Functions

        //- Add to nucleationRate
        virtual void addToNucleationRate
        (
            volScalarField& nucleationRate,
            const label i
        );
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace nucleationModels
} // End namespace diameterModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
