/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::diameterModels::nucleationModels::uniformPhaseTransferEntrainment

Description
    Uniform diameter distribution for uniformPhaseTransferEntrainment.

    Example of dictionary:

    \verbatim
    nucleationModels
    (
        uniformPhaseTransferEntrainment
        {
            velocityGroup   airD;
            interfaces      ((airD and airC));
        }
    );
    \endverbatim

Usage
    \table
        Property      | Description                    | Required | Default
        velocityGroup | Velocity group entrained       | yes      | None
        interfaces    | List of phaseInterface names   | yes      | None
    \endtable

SourceFiles
    uniformPhaseTransferEntrainment.C

\*---------------------------------------------------------------------------*/

#ifndef uniformPhaseTransferEntrainment_H
#define uniformPhaseTransferEntrainment_H

#include "phaseTransferEntrainmentModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diameterModels
{
namespace nucleationModels
{

/*---------------------------------------------------------------------------*\
                  Class uniformPhaseTransferEntrainment Declaration
\*---------------------------------------------------------------------------*/

class uniformPhaseTransferEntrainment
:
    public phaseTransferEntrainmentModel
{
    // Private Member Functions

        //- Add to nucleationRate
        virtual dimensionedScalar distribution(const label i);


public:

    //- Runtime type information
    TypeName("uniformPhaseTransferEntrainment");


    // Constructor

        uniformPhaseTransferEntrainment
        (
            const populationBalanceModel& popBal,
            const dictionary& dict
        );


    //- Destructor
    virtual ~uniformPhaseTransferEntrainment()
    {}
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace nucleationModels
} // End namespace diameterModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
