#! /usr/bin/env python3
"""----------------------------------------------------------------------------
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2020-2022 Helmholtz-Zentrum Dresden-Rossendorf

    HZDR Multiphase Addon for OpenFOAM is free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    HZDR Multiphase Addon for OpenFOAM is distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Description
    Module provides a replacement for RunFunctions

----------------------------------------------------------------------------"""

import argparse
import os
import sys


def main(tool, tool_args, log, flag_append) -> bool:
    """
    Main function created for future needs.
    No particular meaning now except running application
    :param tool:
    :param tool_args:
    :param log:
    :param flag_append:
    :return:
    """
    print(f'Running {tool} on {os.path.abspath(os.curdir)}')
    if flag_append:
        result = os.system(f'{tool} {" ".join(tool_args)} >> {log} 2>&1')
        if result:
            return False
        return True
    result = os.system(f'{tool} {" ".join(tool_args)} > {log} 2>&1')
    if result:
        return False
    return True


if __name__ == '__main__':
    # Parse arguments
    parser = argparse.ArgumentParser(
        description='Wraps a given command into OpenFOAM runApplication')

    # Add positional arguments
    parser.add_argument('--append', action='store_true',
                        help='Append output to existing log file')
    parser.add_argument('--overwrite', action='store_true',
                        help='Overwrite existing log file')
    parser.add_argument('--suffix', type=str, nargs=1, default='',
                        help='Add suffix to log file name')
    parser.add_argument('cmd', help='Command to be wrapped')

    args, cmd_args = parser.parse_known_args()

    # Check if cmd exists
    if os.system(f'which {args.cmd} > /dev/null'):
        sys.exit(f'Error: Can not find app {args.cmd}')

    # Create log file name
    file_log = 'log.' + str(args.cmd).lstrip("./")
    if args.suffix != '':
        file_log = file_log + '.' + args.suffix[0]

    # Check for existing log file
    if not args.overwrite and not args.append and os.path.exists(file_log):
        sys.exit(f'remove log file {file_log} to re-run')

    # Run command and report
    cmd_args = sys.argv[sys.argv.index(args.cmd)+1:]
    if main(args.cmd, cmd_args, file_log, args.append):
        with open(file_log, 'a', encoding='utf-8') as f:
            f.writelines(["\nEnd\n"])
    else:
        print(f'Writing error to {file_log}')
        with open(file_log, 'a', encoding='utf-8') as f:
            f.writelines(["\nFOAM FATAL ERROR"])
        sys.exit(1)
