/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2019-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Global
    readPIDTimeControls

Description
    Read the control parameters used by setPIDDeltaT

\*---------------------------------------------------------------------------*/

adjustTimeStep = cDict.lookupOrDefault("adjustTimeStep", false);

if (adjustTimeStep)
{
    // PID control variable and coefficients
    targetCo = cDict.lookupOrDefault<scalar>("targetCo", defaultTargetCo);
    kP = cDict.lookupOrDefault<scalar>("kP", defaultKP);
    kI = cDict.lookupOrDefault<scalar>("kI", defaultKI);
    kD = cDict.lookupOrDefault<scalar>("kD", defaultKD);

    // Limiters
    maxCo = cDict.lookupOrDefault<scalar>("maxCo", defaultMaxCo);
    minDeltaT = cDict.lookupOrDefault<scalar>("minDeltaT", defaultMinDeltaT);
    maxDeltaT = cDict.lookupOrDefault<scalar>("maxDeltaT", defaultMaxDeltaT);

    if (runTime.timeIndex() == 0)
    {
        if (targetCo < maxCo)
        {
            Info<< "PID controlled time step" << nl
                << "  targetCo        = " << targetCo << nl
                << "  kP              = " << kP << nl
                << "  kI              = " << kI << nl
                << "  kD              = " << kD << nl
                << "  maxCo           = " << maxCo << nl
                << "  minDeltaT       = " << minDeltaT << nl
                << "  maxDeltaT       = " << maxDeltaT << nl
                << endl;

            // Warnings
            if
            (
                cDict.lookupOrDefault<word>("writeControl", "runTime")
             == "adjustableRunTime"
            )
            {
                Warning
                    << "adjustableRunTime may compromise PID controller "
                    << "performance for time step." << nl << endl;
            }

            if (kP > 0 || kI > 0 || kD > 0)
            {
                Warning
                    << "PID coefficients for time step control should be "
                    << "negative." << endl;
            }
        }
        else
        {
            Info<< "Controlled time step" << nl
                << "  maxCo           = " << maxCo << nl
                << "  minDeltaT       = " << minDeltaT << nl
                << "  maxDeltaT       = " << maxDeltaT << nl
                << endl;
        }
    }
}

// ************************************************************************* //
