/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2018-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Global
    setPIDDeltaT

Description
    Set time step size with PID controller to maintain target Courant number
    (targetCo). Reduction of time-step is immediate, but increase is limited to
    a fixed rate of increase (factor 1.2) to avoid unstable oscillations.
    Additionally time step size is bounded by the value from the original time
    step adjustment algorithm, which is controlled with the maximum Courant
    number (maxCo).

\*---------------------------------------------------------------------------*/

if (adjustTimeStep)
{
    // Standard time step control
    scalar stdDeltaT = maxCo*runTime.deltaTValue()/(CoNum + small);
    stdDeltaT = min(stdDeltaT, fvModels.maxDeltaT());
    stdDeltaT = min
    (
        min(stdDeltaT, runTime.deltaTValue() + 0.1*stdDeltaT),
        1.2*runTime.deltaTValue()
    );

    // PID time step control
    scalar PIDDeltaT(great);
    if (targetCo < maxCo)
    {
        const scalar deltaCo(CoNum - targetCo);

        const scalar deltaTP(kP*deltaCo);

        deltaCoSum += kI*deltaCo*runTime.deltaTValue();
        const scalar deltaTI(deltaCoSum);
        Info<< "deltaCoSum = " << deltaCoSum << endl;

        const scalar deltaTD(kD*(deltaCo - deltaCo0)/runTime.deltaTValue());
        deltaCo0 = deltaCo;

        PIDDeltaT = runTime.deltaTValue() + deltaTP + deltaTI + deltaTD;
    }

    // Limit between minDeltaT and maxDeltaT
    runTime.setDeltaT
    (
        max
        (
            min
            (
                (targetCo < maxCo) ? PIDDeltaT : stdDeltaT,
                maxDeltaT
            ),
            minDeltaT
        )
    );

    Info<< "deltaT = " <<  runTime.deltaTValue() << endl;
}

// ************************************************************************* //
