/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2019-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf
    and Technische Universitaet Darmstadt
    and Technische Universitaet Muenchen

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "phaseStructureProperties.H"
#include "volFields.H"
#include "uniformDimensionedFields.H"

// * * * * * * * * * * * * * Private Member Functions  * * * * * * * * * * * //

template<class Type>
void Foam::functionObjects::phaseStructureProperties::registerDimensionedObject
(
    const word name,
    const dimensioned<Type>& obj
) const
{
    const word completeName(IOobject::groupName(name, phaseName_));

    if (foundObject<UniformDimensionedField<Type>>(completeName))
    {
        UniformDimensionedField<Type>& regObj =
            obr_.lookupObjectRef<UniformDimensionedField<Type>>(completeName);

        regObj = obj;
    }
    else
    {
        obr_.store
        (
            new UniformDimensionedField<Type>
            (
                IOobject
                (
                    completeName,
                    mesh_.time().timeName(),
                    mesh_,
                    IOobject::NO_READ,
                    IOobject::NO_WRITE
                ),
                obj
            )
        );
    }
}


// * * * * * * * * * * * * Protected Member Functions  * * * * * * * * * * * //

template<class Type>
void Foam::functionObjects::phaseStructureProperties::combineFields
(
    Field<Type>& field
)
{
    List<Field<Type>> allValues(Pstream::nProcs());

    allValues[Pstream::myProcNo()] = field;

    Pstream::gatherList(allValues);

    if (Pstream::master())
    {
        field =
            ListListOps::combine<Field<Type>>
            (
                allValues,
                accessOp<Field<Type>>()
            );
    }
}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //


template<class Type>
Foam::tmp<Foam::Field<Type>>
Foam::functionObjects::phaseStructureProperties::filterField
(
    const Field<Type>& field
) const
{
    return tmp<Field<Type>>(new Field<Type>(field, cellId_));
}


// ************************************************************************* //
