/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::functionObjects::writeCellCoords

Description
    This function object writes the cell-centre coordinates for a given cell.

    Example of function object specification:
    \verbatim
    writeCellCoords1
    {
        type           writeCellCoords;
        libs ("libHZDRfieldFunctionObjects.so");
        cellId         1;
    }
    \endverbatim

Usage
    \table
        Property     | Description               | Required | Default value
        type         | type name: writeCellCoords | yes      |
        cellId       | cell id                   | yes       |
    \endtable

SourceFiles
    writeCellCoords.C

\*---------------------------------------------------------------------------*/

#ifndef writeCellCoords_H
#define writeCellCoords_H

#include "fvMeshFunctionObject.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace functionObjects
{

/*---------------------------------------------------------------------------*\
                       Class writeCellCoords Declaration
\*---------------------------------------------------------------------------*/

class writeCellCoords
:
    public fvMeshFunctionObject
{
    // Private Data

        //- Cell id
        label cellId_;


public:

    //- Runtime type information
    TypeName("writeCellCoords");


    // Constructors

        //- Construct from Time and dictionary
        writeCellCoords
        (
            const word& name,
            const Time& runTime,
            const dictionary& dict
        );

        //- Disallow default bitwise copy construction
        writeCellCoords(const writeCellCoords&) = delete;


    //- Destructor
    virtual ~writeCellCoords();


    // Member Functions

        //- Read the writeCellCoords data
        virtual bool read(const dictionary&);

        //- Return the list of fields required
        virtual wordList fields() const;

        //- Execute, currently does nothing
        virtual bool execute();

        //- Execute at the final time-loop, currently does nothing
        virtual bool end();

        //- Write the writeCellCoords
        virtual bool write();


    // Member Operators

        //- Disallow default bitwise assignment
        void operator=(const writeCellCoords&) = delete;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace functionObjects
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
