/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM and part of the
    HZDR Multiphase Addon for OpenFOAM.

    Copyright (C) 2021-2022 OpenFOAM Foundation
    and Helmholtz-Zentrum Dresden-Rossendorf

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are free software:
    you can redistribute it and/or modify it under the terms of the
    GNU General Public License as published by the Free Software Foundation,
    either version 3 of the License, or (at your option) any later version.

    OpenFOAM and the HZDR Multiphase Addon for OpenFOAM are distributed in the
    hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM and the HZDR Multiphase Addon for OpenFOAM.
    If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::displacementMeshToMeshSolver

Description
    Mesh motion solver, which interpolates between the usual mesh and an
    additional target mesh. The time dependent interpolation function lambda
    can be chosen to be any Function1.

    Example:
    \verbatim
        dynamicFvMesh   dynamicMotionSolverFvMesh;

        motionSolver    displacementMeshToMeshMotion;

        targetMesh      "targetMesh";

        lambda          linearRamp;
        start           10;
        duration        20;
    \endverbatim

SourceFiles
    displacementMeshToMeshSolver.C

\*---------------------------------------------------------------------------*/

#ifndef displacementMeshToMeshSolver_H
#define displacementMeshToMeshSolver_H

#include "points0MotionSolver.H"
#include "Function1.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
            Class displacementMeshToMeshSolver Declaration
\*---------------------------------------------------------------------------*/

class displacementMeshToMeshSolver
:
    public points0MotionSolver
{
    // Private Data

        const word targetMesh_;

        autoPtr<Function1<scalar>> lambda_;


public:

    //- Runtime type information
    TypeName("displacementMeshToMeshMotion");


    // Constructors

        //- Construct from polyMesh and dictionary
        displacementMeshToMeshSolver
        (
            const word& name,
            const polyMesh&,
            const dictionary&
        );

        //- Disallow default bitwise copy construction
        displacementMeshToMeshSolver
        (
            const displacementMeshToMeshSolver&
        );


    //- Destructor
    ~displacementMeshToMeshSolver();


    // Member Functions

        //- Return point location obtained from the current motion field
        virtual tmp<pointField> curPoints() const;

        //- Solve for motion
        virtual void solve()
        {}


    // Member Operators

        //- Disallow default bitwise assignment
        void operator=(const displacementMeshToMeshSolver&) = delete;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
