# Description

Tutorial demonstrates a setup for simulating stratified flows with
OpenFOAM Hybrid and is based on Fabre et al. (1987)[^1] channel experiment
run 250. The case represents a stratified co-curent flow
of air and water with a relatively smooth interface.

| Case                              | 250      |
|-----------------------------------|----------|
| Liquid flow rate [l/s]            | 3        |
| Gas flow rate [l/s]               | 45.4     |
| Mean liquid level [mm]            | 38       |
| Pressure gradient [Pa/m]          | 2.1      |
| Liquid superficial velocity [m/s] | 0.15     |
| Gas superficial velocity [m/s]    | 2.27     |
| Liquid inlet velocity [m/s]       | 0.394737 |
| Gas inlet velocity [m/s]          | 3.66129  |

# Technical Information

* 2D domain
* height = 0.1 m, length = 13 m, (width = 0.2 m, one cell)
* adjusted g components to account for 0.1% slope in the experiment
  - angle = arctan(slope/100)
  - gx = g*sin(angle)
  - gy = -g*cos(angle)
* channel split in two blocks:
  - water: height 0.038 m, 8 cells in y direction (height)
  - air: height 0.062 m, 12 cells in y direction (3:2 ratio)
  - (note: dy in air is ~10% larger)
  - 156 cells in x direction (length)
  - 3120 total mesh cells
* two inlets (air, water) separated by infinitely thin wall
  - mapping is used for initialising both inlet sections
* simulated time 30 s, about a flow through time for water
* turbulence damping with HZDRinterfaceTurbulenceDamping (see Tekavčič et al.,
  2021[^3], Frederix et al., 2018[^2])
  - No damping in water, damping in air with delta = 1e-4
* interface indicator method with gradAlpha

# Pre-Processing

* setFields:
  * fills the channel with water up to y = 0.038 m
  * set water velocity to (0.395 0 0)
  * set air velocity to (3.66 0 0)

# Post-Processing

FunctionObjects used at run time:
* residuals (p_rgh)
* graphCell

Bash script:
* Gnuplot script createGraphs

Results are compared to experimental data of Fabre et al. (1987)[^1]. Find all
result files in the validation directory.

# Keywords

hybrid, stratified flow, turbulence damping, mapping, co-current flow

# Additional Remarks

* Optional
  - add damping to the water phase
  - mesh refinement (currently very coarse)
  - switch from PISO -> PIMPLE run, use momentumPredictor
* Approximate serial run time is 200 s with the current setup

# Literature

[^1]: Fabre, J., Masbernat, L., & Suzanne, C. (1987).
Experimental data set no. 7: stratified flow, part 1: local structure.
Multiphase Science and Technology, 3(1-4), 285-301.

[^2]: Frederix, E.M.A., Mathur, A., Dovizio, D., Geurts, B.J., & Komen, E.M.J.
(2018). Reynolds-averaged modeling of turbulence damping near a large-scale
interface in two-phase flow. Nuclear Engineering and Design, 333, 122-130.

[^3]: Tekavčič, M., Meller, R., & Schlegel, F. (2021).
Validation of a morphology adaptive multi-field two-fluid model considering
counter-current stratified flow with interfacial turbulence damping.
Nuclear Engineering and Design, 379, 111223.
