/*--------------------------------*- C++ -*----------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
\*---------------------------------------------------------------------------*/
FoamFile
{
    format      ascii;
    class       dictionary;
    object      blockMeshDict;
}
// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

// General macros to create 2D/extruded-2D meshes

changecom(//)changequote([,])
define(calc, [esyscmd(perl -e 'print ($1)')])
define(VCOUNT, 0)
define(vlabel, [[// ]Vertex $1 = VCOUNT define($1, VCOUNT)define([VCOUNT], incr(VCOUNT))])
define(hex2D, hex ($1b $2b $3b $4b $1f $2f $3f $4f)) // Give 2D vertices in anti-clockwise direction
define(patch2D, ($1f $1b $2b $2f)) // Give patch points in anti-clockwise direction, considering contour
define(emptyPatches2D, ($1f $2f $3f $4f) ($1b $4b $3b $2b)) // Give 2D vertices in anti-clockwise direction

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

//              Xi          X0                                 X1

//                                      Wall
//  Y2          6===========7===================================8
//              |           |                                   |
//      Water   |    III    |                IV                 |
//      Inlet   |   Baffle  |                                   |
//              9~~~~~~~~~~~4                                   |   Outlet
//  Y1          3~~~~~~~~~~~4-----------------------------------5
//      Air     |           |                                   |
//      Inlet   |     I     |                II                 |
//  Y0          0===========1===================================2
//                                      Wall

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

convertToMeters 1;


// x coordinates
define(xi, -1   )                   // inlet
define(x0,  0   )                   // origin
define(x1, 12   )                   // outlet

define(Lxi,calc(x0-(xi)))           // length of inlet channel
define(Lxt,calc(x1- x0 ))           // length of test section


// y coordinates
define(y0, 0    )                   // origin
define(y1, 0.038)                   // water level
define(y2, 0.1  )                   // total channel height


// z coordinates
define(z0, 0    )                   // origin
define(z1, 0.2  )                   // depth


// Number of cells
define(nCell, 12)                   // base number of cells

define(nxi,calc(int(Lxi*nCell)))    // cells in inlet region in x
define(nxt,calc(int(Lxt*nCell)))    // cells in test section in x

define(nyl,calc(int(2/3*nCell)))    // cells in liquid in y
define(nyg,             nCell  )    // cells in gas in y

define(nz,              1      )    // cells in z

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

vertices
(
    // bottom
    (xi y0 z0) vlabel(a0b)
    (x0 y0 z0) vlabel(a1b)
    (x1 y0 z0) vlabel(a2b)

    (xi y0 z1) vlabel(a0f)
    (x0 y0 z1) vlabel(a1f)
    (x1 y0 z1) vlabel(a2f)

    // water level
    (xi y1 z0) vlabel(a3b)
    (xi y1 z0) vlabel(a9b) // same geometry as above but additional baffle
    (x0 y1 z0) vlabel(a4b)
    (x1 y1 z0) vlabel(a5b)

    (xi y1 z1) vlabel(a3f)
    (xi y1 z1) vlabel(a9f) // same geometry as above but additional baffle
    (x0 y1 z1) vlabel(a4f)
    (x1 y1 z1) vlabel(a5f)

    // top
    (xi y2 z0) vlabel(a6b)
    (x0 y2 z0) vlabel(a7b)
    (x1 y2 z0) vlabel(a8b)

    (xi y2 z1) vlabel(a6f)
    (x0 y2 z1) vlabel(a7f)
    (x1 y2 z1) vlabel(a8f)
);

blocks
(
    hex2D(a0, a1, a4, a3) (nxi nyl nz) simpleGrading (1 1 1) //liquid inlet
    hex2D(a1, a2, a5, a4) (nxt nyl nz) simpleGrading (1 1 1) //liquid test sec
    hex2D(a9, a4, a7, a6) (nxi nyg nz) simpleGrading (1 1 1) //gas inlet
    hex2D(a4, a5, a8, a7) (nxt nyg nz) simpleGrading (1 1 1) //gas test sec
);

boundary
(
    walls
    {
        type wall;
        faces
        (
            patch2D(a0, a1)
            patch2D(a1, a2)
            patch2D(a8, a7)
            patch2D(a7, a6)
            patch2D(a4, a3) // baffle, liquid side
            patch2D(a9, a4) // baffle, gas side
        );
    }

    outlet
    {
        type patch;
        faces
        (
            patch2D(a2, a5)
            patch2D(a5, a8)
        );
    }

    inlet_liquid
    {
        type        mappedPatch;
        sampleMode  nearestCell;
        offsetMode  uniform;
        offset      (Lxi 0 0);
        faces
        (
            patch2D(a3, a0)
        );
    }

    inlet_gas
    {
        type        mappedPatch;
        sampleMode  nearestCell;
        offsetMode  uniform;
        offset      (Lxi 0 0);
        faces
        (
            patch2D(a6, a9)
        );
    }

    frontAndBack
    {
        type empty;
        faces
        (
            emptyPatches2D(a0, a1, a4, a3)
            emptyPatches2D(a1, a2, a5, a4)
            emptyPatches2D(a9, a4, a7, a6)
            emptyPatches2D(a4, a5, a8, a7)
        );
    }
);

// ************************************************************************* //
